/* GXmlDomRange.c generated by valac 0.34.6, the Vala compiler
 * generated from GXmlDomRange.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/*
 *
 * Copyright (C) 2016  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */
/* FIXME Range could be a set of nodes or a set of character data*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>


#define GXML_TYPE_DOM_RANGE (gxml_dom_range_get_type ())
#define GXML_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRange))
#define GXML_IS_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_RANGE))
#define GXML_DOM_RANGE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRangeIface))

typedef struct _GXmlDomRange GXmlDomRange;
typedef struct _GXmlDomRangeIface GXmlDomRangeIface;

#define GXML_TYPE_DOM_EVENT_TARGET (gxml_dom_event_target_get_type ())
#define GXML_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTarget))
#define GXML_IS_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_TARGET))
#define GXML_DOM_EVENT_TARGET_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTargetIface))

typedef struct _GXmlDomEventTarget GXmlDomEventTarget;
typedef struct _GXmlDomEventTargetIface GXmlDomEventTargetIface;

#define GXML_TYPE_DOM_EVENT_LISTENER (gxml_dom_event_listener_get_type ())
#define GXML_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListener))
#define GXML_IS_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_LISTENER))
#define GXML_DOM_EVENT_LISTENER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListenerIface))

typedef struct _GXmlDomEventListener GXmlDomEventListener;
typedef struct _GXmlDomEventListenerIface GXmlDomEventListenerIface;

#define GXML_TYPE_DOM_EVENT (gxml_dom_event_get_type ())
#define GXML_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEvent))
#define GXML_IS_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT))
#define GXML_DOM_EVENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEventIface))

typedef struct _GXmlDomEvent GXmlDomEvent;
typedef struct _GXmlDomEventIface GXmlDomEventIface;

#define GXML_TYPE_DOM_TIME_STAMP (gxml_dom_time_stamp_get_type ())
#define GXML_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStamp))
#define GXML_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))
#define GXML_IS_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_IS_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_DOM_TIME_STAMP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))

typedef struct _GXmlDomTimeStamp GXmlDomTimeStamp;
typedef struct _GXmlDomTimeStampClass GXmlDomTimeStampClass;

#define GXML_DOM_EVENT_TYPE_PHASE (gxml_dom_event_phase_get_type ())

#define GXML_TYPE_DOM_NODE (gxml_dom_node_get_type ())
#define GXML_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE, GXmlDomNode))
#define GXML_IS_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE))
#define GXML_DOM_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE, GXmlDomNodeIface))

typedef struct _GXmlDomNode GXmlDomNode;
typedef struct _GXmlDomNodeIface GXmlDomNodeIface;

#define GXML_DOM_NODE_TYPE_DOCUMENT_POSITION (gxml_dom_node_document_position_get_type ())

#define GXML_DOM_NODE_TYPE_NODE_TYPE (gxml_dom_node_node_type_get_type ())

#define GXML_TYPE_DOM_PARENT_NODE (gxml_dom_parent_node_get_type ())
#define GXML_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNode))
#define GXML_IS_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PARENT_NODE))
#define GXML_DOM_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNodeIface))

typedef struct _GXmlDomParentNode GXmlDomParentNode;
typedef struct _GXmlDomParentNodeIface GXmlDomParentNodeIface;

#define GXML_TYPE_DOM_CHILD_NODE (gxml_dom_child_node_get_type ())
#define GXML_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNode))
#define GXML_IS_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHILD_NODE))
#define GXML_DOM_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNodeIface))

typedef struct _GXmlDomChildNode GXmlDomChildNode;
typedef struct _GXmlDomChildNodeIface GXmlDomChildNodeIface;

#define GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE (gxml_dom_non_document_type_child_node_get_type ())
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNode))
#define GXML_IS_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE))
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNodeIface))

typedef struct _GXmlDomNonDocumentTypeChildNode GXmlDomNonDocumentTypeChildNode;
typedef struct _GXmlDomNonDocumentTypeChildNodeIface GXmlDomNonDocumentTypeChildNodeIface;

#define GXML_TYPE_DOM_ELEMENT (gxml_dom_element_get_type ())
#define GXML_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElement))
#define GXML_IS_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT))
#define GXML_DOM_ELEMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElementIface))

typedef struct _GXmlDomElement GXmlDomElement;
typedef struct _GXmlDomElementIface GXmlDomElementIface;

#define GXML_TYPE_DOM_HTML_COLLECTION (gxml_dom_html_collection_get_type ())
#define GXML_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollection))
#define GXML_IS_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_HTML_COLLECTION))
#define GXML_DOM_HTML_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollectionIface))

typedef struct _GXmlDomHTMLCollection GXmlDomHTMLCollection;
typedef struct _GXmlDomHTMLCollectionIface GXmlDomHTMLCollectionIface;

#define GXML_TYPE_DOM_TOKEN_LIST (gxml_dom_token_list_get_type ())
#define GXML_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenList))
#define GXML_IS_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TOKEN_LIST))
#define GXML_DOM_TOKEN_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenListIface))

typedef struct _GXmlDomTokenList GXmlDomTokenList;
typedef struct _GXmlDomTokenListIface GXmlDomTokenListIface;

#define GXML_TYPE_DOM_NAMED_NODE_MAP (gxml_dom_named_node_map_get_type ())
#define GXML_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMap))
#define GXML_IS_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP))
#define GXML_DOM_NAMED_NODE_MAP_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMapIface))

typedef struct _GXmlDomNamedNodeMap GXmlDomNamedNodeMap;
typedef struct _GXmlDomNamedNodeMapIface GXmlDomNamedNodeMapIface;

#define GXML_TYPE_DOM_NODE_LIST (gxml_dom_node_list_get_type ())
#define GXML_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeList))
#define GXML_IS_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_LIST))
#define GXML_DOM_NODE_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeListIface))

typedef struct _GXmlDomNodeList GXmlDomNodeList;
typedef struct _GXmlDomNodeListIface GXmlDomNodeListIface;

#define GXML_TYPE_DOM_ELEMENT_LIST (gxml_dom_element_list_get_type ())
#define GXML_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementList))
#define GXML_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))
#define GXML_IS_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_IS_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_DOM_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))

typedef struct _GXmlDomElementList GXmlDomElementList;
typedef struct _GXmlDomElementListClass GXmlDomElementListClass;

#define GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE (gxml_dom_non_element_parent_node_get_type ())
#define GXML_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNode))
#define GXML_IS_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE))
#define GXML_DOM_NON_ELEMENT_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNodeIface))

typedef struct _GXmlDomNonElementParentNode GXmlDomNonElementParentNode;
typedef struct _GXmlDomNonElementParentNodeIface GXmlDomNonElementParentNodeIface;

#define GXML_TYPE_DOM_DOCUMENT (gxml_dom_document_get_type ())
#define GXML_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocument))
#define GXML_IS_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT))
#define GXML_DOM_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocumentIface))

typedef struct _GXmlDomDocument GXmlDomDocument;
typedef struct _GXmlDomDocumentIface GXmlDomDocumentIface;

#define GXML_TYPE_DOM_DOCUMENT_FRAGMENT (gxml_dom_document_fragment_get_type ())
#define GXML_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragment))
#define GXML_IS_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT))
#define GXML_DOM_DOCUMENT_FRAGMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragmentIface))

typedef struct _GXmlDomDocumentFragment GXmlDomDocumentFragment;
typedef struct _GXmlDomDocumentFragmentIface GXmlDomDocumentFragmentIface;

#define GXML_TYPE_DOM_CHARACTER_DATA (gxml_dom_character_data_get_type ())
#define GXML_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterData))
#define GXML_IS_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHARACTER_DATA))
#define GXML_DOM_CHARACTER_DATA_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterDataIface))

typedef struct _GXmlDomCharacterData GXmlDomCharacterData;
typedef struct _GXmlDomCharacterDataIface GXmlDomCharacterDataIface;

#define GXML_TYPE_DOM_TEXT (gxml_dom_text_get_type ())
#define GXML_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TEXT, GXmlDomText))
#define GXML_IS_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TEXT))
#define GXML_DOM_TEXT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TEXT, GXmlDomTextIface))

typedef struct _GXmlDomText GXmlDomText;
typedef struct _GXmlDomTextIface GXmlDomTextIface;

#define GXML_TYPE_DOM_COMMENT (gxml_dom_comment_get_type ())
#define GXML_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomComment))
#define GXML_IS_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_COMMENT))
#define GXML_DOM_COMMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomCommentIface))

typedef struct _GXmlDomComment GXmlDomComment;
typedef struct _GXmlDomCommentIface GXmlDomCommentIface;

#define GXML_TYPE_DOM_PROCESSING_INSTRUCTION (gxml_dom_processing_instruction_get_type ())
#define GXML_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstruction))
#define GXML_IS_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION))
#define GXML_DOM_PROCESSING_INSTRUCTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstructionIface))

typedef struct _GXmlDomProcessingInstruction GXmlDomProcessingInstruction;
typedef struct _GXmlDomProcessingInstructionIface GXmlDomProcessingInstructionIface;

#define GXML_TYPE_DOM_NODE_FILTER (gxml_dom_node_filter_get_type ())
#define GXML_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilter))
#define GXML_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))
#define GXML_IS_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_IS_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_DOM_NODE_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))

typedef struct _GXmlDomNodeFilter GXmlDomNodeFilter;
typedef struct _GXmlDomNodeFilterClass GXmlDomNodeFilterClass;

#define GXML_TYPE_DOM_NODE_ITERATOR (gxml_dom_node_iterator_get_type ())
#define GXML_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIterator))
#define GXML_IS_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_ITERATOR))
#define GXML_DOM_NODE_ITERATOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIteratorIface))

typedef struct _GXmlDomNodeIterator GXmlDomNodeIterator;
typedef struct _GXmlDomNodeIteratorIface GXmlDomNodeIteratorIface;

#define GXML_TYPE_DOM_TREE_WALKER (gxml_dom_tree_walker_get_type ())
#define GXML_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalker))
#define GXML_IS_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TREE_WALKER))
#define GXML_DOM_TREE_WALKER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalkerIface))

typedef struct _GXmlDomTreeWalker GXmlDomTreeWalker;
typedef struct _GXmlDomTreeWalkerIface GXmlDomTreeWalkerIface;

#define GXML_TYPE_DOM_IMPLEMENTATION (gxml_dom_implementation_get_type ())
#define GXML_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementation))
#define GXML_IS_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_IMPLEMENTATION))
#define GXML_DOM_IMPLEMENTATION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementationIface))

typedef struct _GXmlDomImplementation GXmlDomImplementation;
typedef struct _GXmlDomImplementationIface GXmlDomImplementationIface;

#define GXML_TYPE_DOM_DOCUMENT_TYPE (gxml_dom_document_type_get_type ())
#define GXML_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentType))
#define GXML_IS_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE))
#define GXML_DOM_DOCUMENT_TYPE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentTypeIface))

typedef struct _GXmlDomDocumentType GXmlDomDocumentType;
typedef struct _GXmlDomDocumentTypeIface GXmlDomDocumentTypeIface;

#define GXML_TYPE_DOM_XML_DOCUMENT (gxml_dom_xml_document_get_type ())
#define GXML_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocument))
#define GXML_IS_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_XML_DOCUMENT))
#define GXML_DOM_XML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocumentIface))

typedef struct _GXmlDomXMLDocument GXmlDomXMLDocument;
typedef struct _GXmlDomXMLDocumentIface GXmlDomXMLDocumentIface;

#define GXML_TYPE_NODE (gxml_node_get_type ())
#define GXML_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NODE, GXmlNode))
#define GXML_IS_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NODE))
#define GXML_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NODE, GXmlNodeIface))

typedef struct _GXmlNode GXmlNode;
typedef struct _GXmlNodeIface GXmlNodeIface;

#define GXML_TYPE_ELEMENT_LIST (gxml_element_list_get_type ())
#define GXML_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementList))
#define GXML_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))
#define GXML_IS_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_ELEMENT_LIST))
#define GXML_IS_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_ELEMENT_LIST))
#define GXML_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))

typedef struct _GXmlElementList GXmlElementList;
typedef struct _GXmlElementListClass GXmlElementListClass;

#define GXML_TYPE_NAMESPACE (gxml_namespace_get_type ())
#define GXML_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NAMESPACE, GXmlNamespace))
#define GXML_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NAMESPACE))
#define GXML_NAMESPACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NAMESPACE, GXmlNamespaceIface))

typedef struct _GXmlNamespace GXmlNamespace;
typedef struct _GXmlNamespaceIface GXmlNamespaceIface;

#define GXML_TYPE_NODE_TYPE (gxml_node_type_get_type ())

#define GXML_TYPE_DOCUMENT (gxml_document_get_type ())
#define GXML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOCUMENT, GXmlDocument))
#define GXML_IS_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOCUMENT))
#define GXML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOCUMENT, GXmlDocumentIface))

typedef struct _GXmlDocument GXmlDocument;
typedef struct _GXmlDocumentIface GXmlDocumentIface;

#define GXML_DOM_RANGE_TYPE_BOUNDARY_POINTS (gxml_dom_range_boundary_points_get_type ())

#define GXML_TYPE_GDOM_RANGE (gxml_gdom_range_get_type ())
#define GXML_GDOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOM_RANGE, GXmlGDomRange))
#define GXML_GDOM_RANGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOM_RANGE, GXmlGDomRangeClass))
#define GXML_IS_GDOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOM_RANGE))
#define GXML_IS_GDOM_RANGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOM_RANGE))
#define GXML_GDOM_RANGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOM_RANGE, GXmlGDomRangeClass))

typedef struct _GXmlGDomRange GXmlGDomRange;
typedef struct _GXmlGDomRangeClass GXmlGDomRangeClass;
typedef struct _GXmlGDomRangePrivate GXmlGDomRangePrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define GXML_TYPE_DOCUMENT_TYPE (gxml_document_type_get_type ())
#define GXML_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOCUMENT_TYPE, GXmlDocumentType))
#define GXML_IS_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOCUMENT_TYPE))
#define GXML_DOCUMENT_TYPE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOCUMENT_TYPE, GXmlDocumentTypeIface))

typedef struct _GXmlDocumentType GXmlDocumentType;
typedef struct _GXmlDocumentTypeIface GXmlDocumentTypeIface;

typedef enum  {
	GXML_DOM_EVENT_PHASE_NONE = 0,
	GXML_DOM_EVENT_PHASE_CAPTURING_PHASE,
	GXML_DOM_EVENT_PHASE_AT_TARGET,
	GXML_DOM_EVENT_PHASE_BUBBLING_PHASE
} GXmlDomEventPhase;

struct _GXmlDomEventIface {
	GTypeInterface parent_iface;
	void (*stop_propagation) (GXmlDomEvent* self);
	void (*stop_immediate_propagation) (GXmlDomEvent* self);
	void (*prevent_default) (GXmlDomEvent* self);
	void (*init_event) (GXmlDomEvent* self, const gchar* type, gboolean bubbles, gboolean cancelable);
	const gchar* (*get_etype) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_event_target) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_current_target) (GXmlDomEvent* self);
	gboolean (*get_bubbles) (GXmlDomEvent* self);
	gboolean (*get_cancelable) (GXmlDomEvent* self);
	gboolean (*get_is_trusted) (GXmlDomEvent* self);
	GXmlDomTimeStamp* (*get_time_stamp) (GXmlDomEvent* self);
	gboolean (*get_default_prevented) (GXmlDomEvent* self);
	GXmlDomEventPhase (*get_event_phase) (GXmlDomEvent* self);
};

struct _GXmlDomEventListenerIface {
	GTypeInterface parent_iface;
	void (*handle_event) (GXmlDomEventListener* self, GXmlDomEvent* event);
};

struct _GXmlDomEventTargetIface {
	GTypeInterface parent_iface;
	void (*add_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	void (*remove_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	gboolean (*dispatch_event) (GXmlDomEventTarget* self, GXmlDomEvent* event, GError** error);
};

typedef enum  {
	GXML_DOM_NODE_DOCUMENT_POSITION_NONE = 1 << 0,
	GXML_DOM_NODE_DOCUMENT_POSITION_DISCONNECTED = 1 << 1,
	GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING = 1 << 2,
	GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING = 1 << 3,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINS = 1 << 4,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINED_BY = 1 << 5,
	GXML_DOM_NODE_DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC = 1 << 6
} GXmlDomNodeDocumentPosition;

typedef enum  {
	GXML_DOM_NODE_NODE_TYPE_INVALID = 0,
	GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE = 1,
	GXML_DOM_NODE_NODE_TYPE_ATTRIBUTE_NODE,
	GXML_DOM_NODE_NODE_TYPE_TEXT_NODE,
	GXML_DOM_NODE_NODE_TYPE_CDATA_SECTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_REFERENCE_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_NODE,
	GXML_DOM_NODE_NODE_TYPE_PROCESSING_INSTRUCTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_COMMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_FRAGMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_NOTATION_NODE
} GXmlDomNodeNodeType;

struct _GXmlDomChildNodeIface {
	GTypeInterface parent_iface;
	void (*remove) (GXmlDomChildNode* self);
};

struct _GXmlDomNonDocumentTypeChildNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_previous_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
	GXmlDomElement* (*get_next_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
};

struct _GXmlDomHTMLCollectionIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement** (*to_array) (GXmlDomHTMLCollection* self, int* result_length1);
	GXmlDomElement* (*item) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement* (*named_item) (GXmlDomHTMLCollection* self, const gchar* name);
	gint (*get_length) (GXmlDomHTMLCollection* self);
};

struct _GXmlDomTokenListIface {
	GTypeInterface parent_iface;
	gchar* (*item) (GXmlDomTokenList* self, gint index);
	gboolean (*contains) (GXmlDomTokenList* self, const gchar* token, GError** error);
	void (*add) (GXmlDomTokenList* self, gchar** tokens, int tokens_length1, GError** error);
	void (*remove) (GXmlDomTokenList* self, gchar** tokens, int tokens_length1);
	gboolean (*toggle) (GXmlDomTokenList* self, const gchar* token, gboolean force, gboolean _auto_, GError** error);
	gchar* (*to_string) (GXmlDomTokenList* self);
	gint (*get_length) (GXmlDomTokenList* self);
};

struct _GXmlDomNamedNodeMapIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNamedNodeMap* self, gint index);
	GXmlDomNode* (*get_named_item) (GXmlDomNamedNodeMap* self, const gchar* name);
	GXmlDomNode* (*set_named_item) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*remove_named_item) (GXmlDomNamedNodeMap* self, const gchar* name, GError** error);
	GXmlDomNode* (*remove_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* localName, GError** error);
	GXmlDomNode* (*get_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* local_name, GError** error);
	GXmlDomNode* (*set_named_item_ns) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	gint (*get_length) (GXmlDomNamedNodeMap* self);
};

struct _GXmlDomElementIface {
	GTypeInterface parent_iface;
	gchar* (*get_attribute) (GXmlDomElement* self, const gchar* name);
	gchar* (*get_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	void (*set_attribute) (GXmlDomElement* self, const gchar* name, const gchar* value, GError** error);
	void (*set_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* name, const gchar* value, GError** error);
	void (*remove_attribute) (GXmlDomElement* self, const gchar* name);
	void (*remove_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	gboolean (*has_attribute) (GXmlDomElement* self, const gchar* name);
	gboolean (*has_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomElement* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomElement* self, const gchar* class_names);
	gchar* (*get_namespace_uri) (GXmlDomElement* self);
	gchar* (*get_prefix) (GXmlDomElement* self);
	gchar* (*get_local_name) (GXmlDomElement* self);
	gchar* (*get_tag_name) (GXmlDomElement* self);
	gchar* (*get_id) (GXmlDomElement* self);
	void (*set_id) (GXmlDomElement* self, const gchar* value);
	gchar* (*get_class_name) (GXmlDomElement* self);
	void (*set_class_name) (GXmlDomElement* self, const gchar* value);
	GXmlDomTokenList* (*get_class_list) (GXmlDomElement* self);
	GXmlDomNamedNodeMap* (*get_attributes) (GXmlDomElement* self);
};

struct _GXmlDomNodeListIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNodeList* self, gint index);
	gint (*get_length) (GXmlDomNodeList* self);
};

struct _GXmlDomParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*query_selector) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomNodeList* (*query_selector_all) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomElementList* (*get_elements_by_property_value) (GXmlDomParentNode* self, const gchar* property, const gchar* value);
	GXmlDomHTMLCollection* (*get_children) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_first_element_child) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_last_element_child) (GXmlDomParentNode* self);
	gint (*get_child_element_count) (GXmlDomParentNode* self);
};

struct _GXmlDomNonElementParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element_by_id) (GXmlDomNonElementParentNode* self, const gchar* element_id, GError** error);
};

struct _GXmlDomDocumentFragmentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomCharacterDataIface {
	GTypeInterface parent_iface;
	gchar* (*substring_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*append_data) (GXmlDomCharacterData* self, const gchar* data);
	void (*insert_data) (GXmlDomCharacterData* self, gint offset, const gchar* data, GError** error);
	void (*delete_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*replace_data) (GXmlDomCharacterData* self, gint offset, gint count, const gchar* data, GError** error);
	gchar* (*get_data) (GXmlDomCharacterData* self);
	void (*set_data) (GXmlDomCharacterData* self, const gchar* value);
	gint (*get_length) (GXmlDomCharacterData* self);
};

struct _GXmlDomTextIface {
	GTypeInterface parent_iface;
	GXmlDomText* (*split_text) (GXmlDomText* self, gint offset, GError** error);
	gchar* (*get_whole_text) (GXmlDomText* self);
};

struct _GXmlDomCommentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomProcessingInstructionIface {
	GTypeInterface parent_iface;
	gchar* (*get_target) (GXmlDomProcessingInstruction* self);
};

struct _GXmlDomNodeIteratorIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*next_node) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*previous_node) (GXmlDomNodeIterator* self);
	void (*detach) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_root) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_reference_node) (GXmlDomNodeIterator* self);
	gboolean (*get_pointer_before_reference_node) (GXmlDomNodeIterator* self);
	gint (*get_what_to_show) (GXmlDomNodeIterator* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomNodeIterator* self);
};

struct _GXmlDomTreeWalkerIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*parentNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*firstChild) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*lastChild) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previousSibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*nextSibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previousNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*nextNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_root) (GXmlDomTreeWalker* self);
	gint (*get_what_to_show) (GXmlDomTreeWalker* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_current_node) (GXmlDomTreeWalker* self);
};

struct _GXmlDomDocumentTypeIface {
	GTypeInterface parent_iface;
	const gchar* (*get_name) (GXmlDomDocumentType* self);
	const gchar* (*get_public_id) (GXmlDomDocumentType* self);
	const gchar* (*get_system_id) (GXmlDomDocumentType* self);
};

struct _GXmlDomXMLDocumentIface {
	GTypeInterface parent_iface;
};

struct _GXmlNamespaceIface {
	GTypeInterface parent_iface;
	gchar* (*get_uri) (GXmlNamespace* self);
	gchar* (*get_prefix) (GXmlNamespace* self);
};

typedef enum  {
	GXML_NODE_TYPE_INVALID = 0,
	GXML_NODE_TYPE_ELEMENT = 1,
	GXML_NODE_TYPE_ATTRIBUTE,
	GXML_NODE_TYPE_TEXT,
	GXML_NODE_TYPE_CDATA_SECTION,
	GXML_NODE_TYPE_ENTITY_REFERENCE,
	GXML_NODE_TYPE_ENTITY,
	GXML_NODE_TYPE_PROCESSING_INSTRUCTION,
	GXML_NODE_TYPE_COMMENT,
	GXML_NODE_TYPE_DOCUMENT,
	GXML_NODE_TYPE_DOCUMENT_TYPE,
	GXML_NODE_TYPE_DOCUMENT_FRAGMENT,
	GXML_NODE_TYPE_NOTATION
} GXmlNodeType;

struct _GXmlNodeIface {
	GTypeInterface parent_iface;
	GXmlNode* (*get) (GXmlNode* self, const gchar* key);
	GXmlElementList* (*get_elements_by_property_value) (GXmlNode* self, const gchar* property, const gchar* value);
	GXmlElementList* (*get_elements_by_name) (GXmlNode* self, const gchar* name);
	GXmlElementList* (*get_elements_by_name_ns) (GXmlNode* self, const gchar* name, const gchar* ns);
	gchar* (*to_string) (GXmlNode* self);
	gboolean (*set_namespace) (GXmlNode* self, const gchar* uri, const gchar* prefix);
	gchar* (*ns_prefix) (GXmlNode* self);
	gchar* (*ns_uri) (GXmlNode* self);
	GeeList* (*get_namespaces) (GXmlNode* self);
	GeeBidirList* (*get_children_nodes) (GXmlNode* self);
	GeeMap* (*get_attrs) (GXmlNode* self);
	gchar* (*get_name) (GXmlNode* self);
	gchar* (*get_value) (GXmlNode* self);
	void (*set_value) (GXmlNode* self, const gchar* value);
	GXmlNodeType (*get_type_node) (GXmlNode* self);
	GXmlDocument* (*get_document) (GXmlNode* self);
	GXmlNode* (*get_parent) (GXmlNode* self);
};

struct _GXmlDocumentIface {
	GTypeInterface parent_iface;
	GXmlNode* (*create_element) (GXmlDocument* self, const gchar* name, GError** error);
	GXmlNode* (*create_text) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_comment) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_cdata) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_pi) (GXmlDocument* self, const gchar* target, const gchar* data);
	gboolean (*save) (GXmlDocument* self, GCancellable* cancellable, GError** error);
	gboolean (*save_as) (GXmlDocument* self, GFile* f, GCancellable* cancellable, GError** error);
	gboolean (*get_indent) (GXmlDocument* self);
	void (*set_indent) (GXmlDocument* self, gboolean value);
	gboolean (*get_ns_top) (GXmlDocument* self);
	void (*set_ns_top) (GXmlDocument* self, gboolean value);
	gboolean (*get_prefix_default_ns) (GXmlDocument* self);
	void (*set_prefix_default_ns) (GXmlDocument* self, gboolean value);
	gboolean (*get_backup) (GXmlDocument* self);
	void (*set_backup) (GXmlDocument* self, gboolean value);
	GXmlNode* (*get_root) (GXmlDocument* self);
	GFile* (*get_file) (GXmlDocument* self);
	void (*set_file) (GXmlDocument* self, GFile* value);
};

struct _GXmlDomImplementationIface {
	GTypeInterface parent_iface;
	GXmlDomDocumentType* (*create_document_type) (GXmlDomImplementation* self, const gchar* qualified_name, const gchar* public_id, const gchar* system_id, GError** error);
	GXmlDomXMLDocument* (*create_document) (GXmlDomImplementation* self, const gchar* nspace, const gchar* qualified_name, GXmlDomDocumentType* doctype, GError** error);
	GXmlDocument* (*create_html_document) (GXmlDomImplementation* self, const gchar* title);
	gboolean (*has_feature) (GXmlDomImplementation* self);
};

struct _GXmlDomDocumentIface {
	GTypeInterface parent_iface;
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomDocument* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomDocument* self, const gchar* classNames);
	GXmlDomElement* (*create_element) (GXmlDomDocument* self, const gchar* local_name, GError** error);
	GXmlDomElement* (*create_element_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* qualified_name, GError** error);
	GXmlDomDocumentFragment* (*create_document_fragment) (GXmlDomDocument* self);
	GXmlDomText* (*create_text_node) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomComment* (*create_comment) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomProcessingInstruction* (*create_processing_instruction) (GXmlDomDocument* self, const gchar* target, const gchar* data, GError** error);
	GXmlDomNode* (*import_node) (GXmlDomDocument* self, GXmlDomNode* node, gboolean deep, GError** error);
	GXmlDomNode* (*adopt_node) (GXmlDomDocument* self, GXmlDomNode* node, GError** error);
	GXmlDomEvent* (*create_event) (GXmlDomDocument* self, const gchar* interface, GError** error);
	GXmlDomRange* (*create_range) (GXmlDomDocument* self);
	GXmlDomNodeIterator* (*create_node_iterator) (GXmlDomDocument* self, GXmlDomNode* root, gint whatToShow, GXmlDomNodeFilter* filter);
	GXmlDomTreeWalker* (*create_tree_walker) (GXmlDomDocument* self, GXmlDomNode* root, gint what_to_show, GXmlDomNodeFilter* filter);
	GXmlDomImplementation* (*get_implementation) (GXmlDomDocument* self);
	const gchar* (*get_url) (GXmlDomDocument* self);
	const gchar* (*get_document_uri) (GXmlDomDocument* self);
	const gchar* (*get_origin) (GXmlDomDocument* self);
	const gchar* (*get_compat_mode) (GXmlDomDocument* self);
	const gchar* (*get_character_set) (GXmlDomDocument* self);
	const gchar* (*get_content_type) (GXmlDomDocument* self);
	GXmlDomDocumentType* (*get_doctype) (GXmlDomDocument* self);
	GXmlDomElement* (*get_document_element) (GXmlDomDocument* self);
};

struct _GXmlDomNodeIface {
	GTypeInterface parent_iface;
	gboolean (*has_child_nodes) (GXmlDomNode* self);
	void (*normalize) (GXmlDomNode* self);
	gboolean (*is_equal_node) (GXmlDomNode* self, GXmlDomNode* node);
	GXmlDomNodeDocumentPosition (*compare_document_position) (GXmlDomNode* self, GXmlDomNode* other);
	gboolean (*contains) (GXmlDomNode* self, GXmlDomNode* other);
	gchar* (*lookup_prefix) (GXmlDomNode* self, const gchar* nspace);
	gchar* (*lookup_namespace_uri) (GXmlDomNode* self, const gchar* prefix);
	gboolean (*is_default_namespace) (GXmlDomNode* self, const gchar* nspace);
	GXmlDomNode* (*insert_before) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*append_child) (GXmlDomNode* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*replace_child) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*remove_child) (GXmlDomNode* self, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*clone_node) (GXmlDomNode* self, gboolean deep, GError** error);
	GXmlDomNodeNodeType (*get_node_type) (GXmlDomNode* self);
	gchar* (*get_node_name) (GXmlDomNode* self);
	const gchar* (*get_base_uri) (GXmlDomNode* self);
	GXmlDomDocument* (*get_owner_document) (GXmlDomNode* self);
	void (*set_owner_document) (GXmlDomNode* self, GXmlDomDocument* value);
	GXmlDomNode* (*get_parent_node) (GXmlDomNode* self);
	GXmlDomElement* (*get_parent_element) (GXmlDomNode* self);
	GXmlDomNodeList* (*get_child_nodes) (GXmlDomNode* self);
	GXmlDomNode* (*get_first_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_last_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_previous_sibling) (GXmlDomNode* self);
	GXmlDomNode* (*get_next_sibling) (GXmlDomNode* self);
	gchar* (*get_node_value) (GXmlDomNode* self);
	void (*set_node_value) (GXmlDomNode* self, const gchar* value);
	gchar* (*get_text_content) (GXmlDomNode* self);
	void (*set_text_content) (GXmlDomNode* self, const gchar* value);
};

typedef enum  {
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_START = 0,
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_START
} GXmlDomRangeBoundaryPoints;

struct _GXmlDomRangeIface {
	GTypeInterface parent_iface;
	void (*set_start) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_end) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_start_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_start_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*collapse) (GXmlDomRange* self, gboolean to_start, GError** error);
	void (*select_node) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*select_node_contents) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	gint (*compare_boundary_points) (GXmlDomRange* self, GXmlDomRangeBoundaryPoints how, GXmlDomRange* sourceRange, GError** error);
	void (*delete_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*extract_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*clone_contents) (GXmlDomRange* self, GError** error);
	void (*insert_node) (GXmlDomRange* self, GXmlDomNode* node);
	void (*surround_contents) (GXmlDomRange* self, GXmlDomNode* newParent);
	GXmlDomRange* (*clone_range) (GXmlDomRange* self);
	void (*detach) (GXmlDomRange* self);
	gboolean (*is_point_in_range) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gshort (*compare_point) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gboolean (*intersects_node) (GXmlDomRange* self, GXmlDomNode* node);
	gchar* (*to_string) (GXmlDomRange* self);
	GXmlDomNode* (*get_start_container) (GXmlDomRange* self);
	gint (*get_start_offset) (GXmlDomRange* self);
	GXmlDomNode* (*get_end_container) (GXmlDomRange* self);
	gint (*get_end_offset) (GXmlDomRange* self);
	gboolean (*get_collapsed) (GXmlDomRange* self);
	GXmlDomNode* (*get_common_ancestor_container) (GXmlDomRange* self);
};

struct _GXmlGDomRange {
	GObject parent_instance;
	GXmlGDomRangePrivate * priv;
	GXmlDomDocument* _document;
	GXmlDomNode* _start_container;
	gint _start_offset;
	GXmlDomNode* _end_container;
	gint _end_offset;
	gboolean _collapse;
	GXmlDomNode* _common_ancestor_container;
};

struct _GXmlGDomRangeClass {
	GObjectClass parent_class;
};

typedef enum  {
	GXML_DOM_ERROR_INDEX_SIZE_ERROR = 1,
	GXML_DOM_ERROR_DOMSTRING_SIZE_ERROR,
	GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR,
	GXML_DOM_ERROR_WRONG_DOCUMENT_ERROR,
	GXML_DOM_ERROR_INVALID_CHARACTER_ERROR,
	GXML_DOM_ERROR_NO_DATA_ALLOWED_ERROR,
	GXML_DOM_ERROR_NO_MODIFICATION_ALLOWED_ERROR,
	GXML_DOM_ERROR_NOT_FOUND_ERROR,
	GXML_DOM_ERROR_NOT_SUPPORTED_ERROR,
	GXML_DOM_ERROR_INUSE_ATTRIBUTE_ERROR,
	GXML_DOM_ERROR_INVALID_STATE_ERROR,
	GXML_DOM_ERROR_SYNTAX_ERROR,
	GXML_DOM_ERROR_INVALID_MODIFICATION_ERROR,
	GXML_DOM_ERROR_NAMESPACE_ERROR,
	GXML_DOM_ERROR_INVALID_ACCESS_ERROR,
	GXML_DOM_ERROR_VALIDATION_ERROR,
	GXML_DOM_ERROR_TYPE_MISMATCH_ERROR,
	GXML_DOM_ERROR_SECURITY_ERROR,
	GXML_DOM_ERROR_NETWORK_ERROR,
	GXML_DOM_ERROR_ABORT_ERROR,
	GXML_DOM_ERROR_URL_MISMATCH_ERROR,
	GXML_DOM_ERROR_QUOTA_EXCEEDED_ERROR,
	GXML_DOM_ERROR_TIME_OUT_ERROR,
	GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR,
	GXML_DOM_ERROR_DATA_CLONE_ERROR
} GXmlDomError;
#define GXML_DOM_ERROR gxml_dom_error_quark ()
struct _GXmlDocumentTypeIface {
	GTypeInterface parent_iface;
};


static gpointer gxml_gdom_range_parent_class = NULL;
static GXmlDomRangeIface* gxml_gdom_range_gxml_dom_range_parent_iface = NULL;

GType gxml_dom_time_stamp_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_phase_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_listener_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_target_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_document_position_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_node_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_document_type_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_html_collection_get_type (void) G_GNUC_CONST;
GType gxml_dom_token_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_named_node_map_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_element_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_fragment_get_type (void) G_GNUC_CONST;
GType gxml_dom_character_data_get_type (void) G_GNUC_CONST;
GType gxml_dom_text_get_type (void) G_GNUC_CONST;
GType gxml_dom_comment_get_type (void) G_GNUC_CONST;
GType gxml_dom_processing_instruction_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_filter_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_iterator_get_type (void) G_GNUC_CONST;
GType gxml_dom_tree_walker_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_xml_document_get_type (void) G_GNUC_CONST;
GType gxml_element_list_get_type (void) G_GNUC_CONST;
GType gxml_namespace_get_type (void) G_GNUC_CONST;
GType gxml_node_type_get_type (void) G_GNUC_CONST;
GType gxml_node_get_type (void) G_GNUC_CONST;
GType gxml_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_implementation_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_boundary_points_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_get_type (void) G_GNUC_CONST;
GType gxml_gdom_range_get_type (void) G_GNUC_CONST;
enum  {
	GXML_GDOM_RANGE_DUMMY_PROPERTY,
	GXML_GDOM_RANGE_START_CONTAINER,
	GXML_GDOM_RANGE_START_OFFSET,
	GXML_GDOM_RANGE_END_CONTAINER,
	GXML_GDOM_RANGE_END_OFFSET,
	GXML_GDOM_RANGE_COLLAPSED,
	GXML_GDOM_RANGE_COMMON_ANCESTOR_CONTAINER
};
GXmlGDomRange* gxml_gdom_range_new (GXmlDomDocument* doc);
GXmlGDomRange* gxml_gdom_range_construct (GType object_type, GXmlDomDocument* doc);
static void gxml_gdom_range_real_set_start (GXmlDomRange* base, GXmlDomNode* node, gint offset, GError** error);
GQuark gxml_dom_error_quark (void);
GType gxml_document_type_get_type (void) G_GNUC_CONST;
gint gxml_dom_character_data_get_length (GXmlDomCharacterData* self);
GXmlDomNodeList* gxml_dom_node_get_child_nodes (GXmlDomNode* self);
gint gxml_dom_node_list_get_length (GXmlDomNodeList* self);
GXmlDomNode* gxml_dom_node_get_parent_node (GXmlDomNode* self);
static void gxml_gdom_range_real_set_end (GXmlDomRange* base, GXmlDomNode* node, gint offset, GError** error);
static void gxml_gdom_range_real_set_start_before (GXmlDomRange* base, GXmlDomNode* node, GError** error);
void gxml_dom_range_set_start (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
static void gxml_gdom_range_real_set_start_after (GXmlDomRange* base, GXmlDomNode* node, GError** error);
static void gxml_gdom_range_real_set_end_before (GXmlDomRange* base, GXmlDomNode* node, GError** error);
void gxml_dom_range_set_end (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
static void gxml_gdom_range_real_set_end_after (GXmlDomRange* base, GXmlDomNode* node, GError** error);
static void gxml_gdom_range_real_collapse (GXmlDomRange* base, gboolean to_start, GError** error);
static void gxml_gdom_range_real_select_node (GXmlDomRange* base, GXmlDomNode* node, GError** error);
static void gxml_gdom_range_real_select_node_contents (GXmlDomRange* base, GXmlDomNode* node, GError** error);
static gint gxml_gdom_range_real_compare_boundary_points (GXmlDomRange* base, GXmlDomRangeBoundaryPoints how, GXmlDomRange* source_range, GError** error);
GXmlDomNode* gxml_dom_range_get_start_container (GXmlDomRange* self);
GXmlDomNode* gxml_dom_range_get_end_container (GXmlDomRange* self);
static void gxml_gdom_range_real_delete_contents (GXmlDomRange* base, GError** error);
static GXmlDomDocumentFragment* gxml_gdom_range_real_extract_contents (GXmlDomRange* base, GError** error);
static GXmlDomDocumentFragment* gxml_gdom_range_real_clone_contents (GXmlDomRange* base, GError** error);
static void gxml_gdom_range_real_insert_node (GXmlDomRange* base, GXmlDomNode* node);
static void gxml_gdom_range_real_surround_contents (GXmlDomRange* base, GXmlDomNode* newParent);
static GXmlDomRange* gxml_gdom_range_real_clone_range (GXmlDomRange* base);
static void gxml_gdom_range_real_detach (GXmlDomRange* base);
static gboolean gxml_gdom_range_real_is_point_in_range (GXmlDomRange* base, GXmlDomNode* node, gint offset);
static gshort gxml_gdom_range_real_compare_point (GXmlDomRange* base, GXmlDomNode* node, gint offset);
static gboolean gxml_gdom_range_real_intersects_node (GXmlDomRange* base, GXmlDomNode* node);
static gchar* gxml_gdom_range_real_to_string (GXmlDomRange* base);
static void gxml_gdom_range_finalize (GObject* obj);
gint gxml_dom_range_get_start_offset (GXmlDomRange* self);
gint gxml_dom_range_get_end_offset (GXmlDomRange* self);
gboolean gxml_dom_range_get_collapsed (GXmlDomRange* self);
GXmlDomNode* gxml_dom_range_get_common_ancestor_container (GXmlDomRange* self);
static void _vala_gxml_gdom_range_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);


static gpointer _g_object_ref0 (gpointer self) {
	return self ? g_object_ref (self) : NULL;
}


GXmlGDomRange* gxml_gdom_range_construct (GType object_type, GXmlDomDocument* doc) {
	GXmlGDomRange * self = NULL;
	GXmlDomDocument* _tmp0_ = NULL;
	GXmlDomDocument* _tmp1_ = NULL;
	GXmlDomDocument* _tmp2_ = NULL;
	GXmlDomNode* _tmp3_ = NULL;
	GXmlDomDocument* _tmp4_ = NULL;
	GXmlDomNode* _tmp5_ = NULL;
	GXmlDomDocument* _tmp6_ = NULL;
	GXmlDomNode* _tmp7_ = NULL;
	g_return_val_if_fail (doc != NULL, NULL);
	self = (GXmlGDomRange*) g_object_new (object_type, NULL);
	_tmp0_ = doc;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	_g_object_unref0 (self->_document);
	self->_document = _tmp1_;
	_tmp2_ = doc;
	_tmp3_ = _g_object_ref0 ((GXmlDomNode*) _tmp2_);
	_g_object_unref0 (self->_start_container);
	self->_start_container = _tmp3_;
	_tmp4_ = doc;
	_tmp5_ = _g_object_ref0 ((GXmlDomNode*) _tmp4_);
	_g_object_unref0 (self->_end_container);
	self->_end_container = _tmp5_;
	self->_start_offset = 0;
	self->_end_offset = 0;
	_tmp6_ = doc;
	_tmp7_ = _g_object_ref0 ((GXmlDomNode*) _tmp6_);
	_g_object_unref0 (self->_common_ancestor_container);
	self->_common_ancestor_container = _tmp7_;
	return self;
}


GXmlGDomRange* gxml_gdom_range_new (GXmlDomDocument* doc) {
	return gxml_gdom_range_construct (GXML_TYPE_GDOM_RANGE, doc);
}


static void gxml_gdom_range_real_set_start (GXmlDomRange* base, GXmlDomNode* node, gint offset, GError** error) {
	GXmlGDomRange * self;
	GXmlDomNode* _tmp0_ = NULL;
	GXmlDomNode* _tmp3_ = NULL;
	GXmlDomNode* _tmp24_ = NULL;
	GXmlDomNode* _tmp54_ = NULL;
	GXmlDomNode* _tmp55_ = NULL;
	gint _tmp56_ = 0;
	GError * _inner_error_ = NULL;
	self = (GXmlGDomRange*) base;
	g_return_if_fail (node != NULL);
	_tmp0_ = node;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT_TYPE)) {
		const gchar* _tmp1_ = NULL;
		GError* _tmp2_ = NULL;
		_tmp1_ = _ ("Invalid node type to start");
		_tmp2_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR, _tmp1_);
		_inner_error_ = _tmp2_;
		g_propagate_error (error, _inner_error_);
		return;
	}
	_tmp3_ = node;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_DOCUMENT_TYPE)) {
		gint _tmp4_ = 0;
		_tmp4_ = offset;
		if (_tmp4_ > 0) {
			const gchar* _tmp5_ = NULL;
			GError* _tmp6_ = NULL;
			_tmp5_ = _ ("Invalid offset for node to start: for document type");
			_tmp6_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INDEX_SIZE_ERROR, _tmp5_);
			_inner_error_ = _tmp6_;
			g_propagate_error (error, _inner_error_);
			return;
		} else {
			GXmlDomNode* _tmp7_ = NULL;
			_tmp7_ = node;
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, GXML_TYPE_DOM_CHARACTER_DATA)) {
				gint _tmp8_ = 0;
				GXmlDomNode* _tmp9_ = NULL;
				gint _tmp10_ = 0;
				gint _tmp11_ = 0;
				_tmp8_ = offset;
				_tmp9_ = node;
				_tmp10_ = gxml_dom_character_data_get_length (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_DOM_CHARACTER_DATA) ? ((GXmlDomCharacterData*) _tmp9_) : NULL);
				_tmp11_ = _tmp10_;
				if (_tmp8_ > _tmp11_) {
					const gchar* _tmp12_ = NULL;
					GError* _tmp13_ = NULL;
					_tmp12_ = _ ("Invalid offset for node to start: for character data");
					_tmp13_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INDEX_SIZE_ERROR, _tmp12_);
					_inner_error_ = _tmp13_;
					g_propagate_error (error, _inner_error_);
					return;
				} else {
					gint _tmp14_ = 0;
					GXmlDomNode* _tmp15_ = NULL;
					GXmlDomNodeList* _tmp16_ = NULL;
					GXmlDomNodeList* _tmp17_ = NULL;
					GXmlDomNodeList* _tmp18_ = NULL;
					gint _tmp19_ = 0;
					gint _tmp20_ = 0;
					gboolean _tmp21_ = FALSE;
					_tmp14_ = offset;
					_tmp15_ = node;
					_tmp16_ = gxml_dom_node_get_child_nodes (_tmp15_);
					_tmp17_ = _tmp16_;
					_tmp18_ = _tmp17_;
					_tmp19_ = gxml_dom_node_list_get_length (_tmp18_);
					_tmp20_ = _tmp19_;
					_tmp21_ = _tmp14_ > _tmp20_;
					_g_object_unref0 (_tmp18_);
					if (_tmp21_) {
						const gchar* _tmp22_ = NULL;
						GError* _tmp23_ = NULL;
						_tmp22_ = _ ("Invalid offset for node to start: for children number");
						_tmp23_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INDEX_SIZE_ERROR, _tmp22_);
						_inner_error_ = _tmp23_;
						g_propagate_error (error, _inner_error_);
						return;
					}
				}
			}
		}
	}
	_tmp24_ = self->_end_container;
	if (_tmp24_ != NULL) {
		GXmlDomNode* _tmp25_ = NULL;
		GXmlDomNode* _tmp26_ = NULL;
		GXmlDomNode* _tmp27_ = NULL;
		GXmlDomNode* _tmp28_ = NULL;
		GXmlDomNode* _tmp29_ = NULL;
		GXmlDomNode* _tmp30_ = NULL;
		GXmlDomNode* _tmp31_ = NULL;
		GXmlDomNode* _tmp32_ = NULL;
		gboolean _tmp33_ = FALSE;
		_tmp25_ = node;
		_tmp26_ = gxml_dom_node_get_parent_node (_tmp25_);
		_tmp27_ = _tmp26_;
		_tmp28_ = _tmp27_;
		_tmp29_ = self->_end_container;
		_tmp30_ = gxml_dom_node_get_parent_node (_tmp29_);
		_tmp31_ = _tmp30_;
		_tmp32_ = _tmp31_;
		_tmp33_ = _tmp28_ != _tmp32_;
		_g_object_unref0 (_tmp32_);
		_g_object_unref0 (_tmp28_);
		if (_tmp33_) {
			GXmlDomNode* _tmp34_ = NULL;
			GXmlDomNode* _tmp35_ = NULL;
			gint _tmp36_ = 0;
			_tmp34_ = self->_end_container;
			_tmp35_ = _g_object_ref0 (_tmp34_);
			_g_object_unref0 (self->_start_container);
			self->_start_container = _tmp35_;
			_tmp36_ = self->_end_offset;
			self->_start_offset = _tmp36_;
		} else {
			gint ni = 0;
			GXmlDomNode* _tmp37_ = NULL;
			GXmlDomNode* _tmp38_ = NULL;
			GXmlDomNode* _tmp39_ = NULL;
			GXmlDomNode* _tmp40_ = NULL;
			GXmlDomNodeList* _tmp41_ = NULL;
			GXmlDomNodeList* _tmp42_ = NULL;
			GXmlDomNodeList* _tmp43_ = NULL;
			GXmlDomNode* _tmp44_ = NULL;
			gint _tmp45_ = 0;
			gint _tmp46_ = 0;
			gint _tmp47_ = 0;
			gint _tmp48_ = 0;
			GXmlDomNode* _tmp51_ = NULL;
			GXmlDomNode* _tmp52_ = NULL;
			gint _tmp53_ = 0;
			_tmp37_ = node;
			_tmp38_ = gxml_dom_node_get_parent_node (_tmp37_);
			_tmp39_ = _tmp38_;
			_tmp40_ = _tmp39_;
			_tmp41_ = gxml_dom_node_get_child_nodes (_tmp40_);
			_tmp42_ = _tmp41_;
			_tmp43_ = _tmp42_;
			_tmp44_ = node;
			_tmp45_ = gee_list_index_of ((GeeList*) _tmp43_, _tmp44_);
			_tmp46_ = _tmp45_;
			_g_object_unref0 (_tmp43_);
			_g_object_unref0 (_tmp40_);
			ni = _tmp46_;
			_tmp47_ = ni;
			_tmp48_ = offset;
			if (_tmp47_ > _tmp48_) {
				GXmlDomNode* _tmp49_ = NULL;
				GXmlDomNode* _tmp50_ = NULL;
				_tmp49_ = node;
				_tmp50_ = _g_object_ref0 (_tmp49_);
				_g_object_unref0 (self->_end_container);
				self->_end_container = _tmp50_;
			}
			_tmp51_ = node;
			_tmp52_ = _g_object_ref0 (_tmp51_);
			_g_object_unref0 (self->_start_container);
			self->_start_container = _tmp52_;
			_tmp53_ = offset;
			self->_start_offset = _tmp53_;
		}
	}
	_tmp54_ = node;
	_tmp55_ = _g_object_ref0 (_tmp54_);
	_g_object_unref0 (self->_start_container);
	self->_start_container = _tmp55_;
	_tmp56_ = offset;
	self->_start_offset = _tmp56_;
}


static void gxml_gdom_range_real_set_end (GXmlDomRange* base, GXmlDomNode* node, gint offset, GError** error) {
	GXmlGDomRange * self;
	GXmlDomNode* _tmp0_ = NULL;
	GXmlDomNode* _tmp3_ = NULL;
	GXmlDomNode* _tmp24_ = NULL;
	GXmlDomNode* _tmp51_ = NULL;
	GXmlDomNode* _tmp52_ = NULL;
	gint _tmp53_ = 0;
	GError * _inner_error_ = NULL;
	self = (GXmlGDomRange*) base;
	g_return_if_fail (node != NULL);
	_tmp0_ = node;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT_TYPE)) {
		const gchar* _tmp1_ = NULL;
		GError* _tmp2_ = NULL;
		_tmp1_ = _ ("Invalid node type to start");
		_tmp2_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR, _tmp1_);
		_inner_error_ = _tmp2_;
		g_propagate_error (error, _inner_error_);
		return;
	}
	_tmp3_ = node;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_DOCUMENT_TYPE)) {
		gint _tmp4_ = 0;
		_tmp4_ = offset;
		if (_tmp4_ > 0) {
			const gchar* _tmp5_ = NULL;
			GError* _tmp6_ = NULL;
			_tmp5_ = _ ("Invalid offset for node to start: for document type");
			_tmp6_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INDEX_SIZE_ERROR, _tmp5_);
			_inner_error_ = _tmp6_;
			g_propagate_error (error, _inner_error_);
			return;
		} else {
			GXmlDomNode* _tmp7_ = NULL;
			_tmp7_ = node;
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, GXML_TYPE_DOM_CHARACTER_DATA)) {
				gint _tmp8_ = 0;
				GXmlDomNode* _tmp9_ = NULL;
				gint _tmp10_ = 0;
				gint _tmp11_ = 0;
				_tmp8_ = offset;
				_tmp9_ = node;
				_tmp10_ = gxml_dom_character_data_get_length (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_DOM_CHARACTER_DATA) ? ((GXmlDomCharacterData*) _tmp9_) : NULL);
				_tmp11_ = _tmp10_;
				if (_tmp8_ > _tmp11_) {
					const gchar* _tmp12_ = NULL;
					GError* _tmp13_ = NULL;
					_tmp12_ = _ ("Invalid offset for node to start: for character data");
					_tmp13_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INDEX_SIZE_ERROR, _tmp12_);
					_inner_error_ = _tmp13_;
					g_propagate_error (error, _inner_error_);
					return;
				} else {
					gint _tmp14_ = 0;
					GXmlDomNode* _tmp15_ = NULL;
					GXmlDomNodeList* _tmp16_ = NULL;
					GXmlDomNodeList* _tmp17_ = NULL;
					GXmlDomNodeList* _tmp18_ = NULL;
					gint _tmp19_ = 0;
					gint _tmp20_ = 0;
					gboolean _tmp21_ = FALSE;
					_tmp14_ = offset;
					_tmp15_ = node;
					_tmp16_ = gxml_dom_node_get_child_nodes (_tmp15_);
					_tmp17_ = _tmp16_;
					_tmp18_ = _tmp17_;
					_tmp19_ = gxml_dom_node_list_get_length (_tmp18_);
					_tmp20_ = _tmp19_;
					_tmp21_ = _tmp14_ > _tmp20_;
					_g_object_unref0 (_tmp18_);
					if (_tmp21_) {
						const gchar* _tmp22_ = NULL;
						GError* _tmp23_ = NULL;
						_tmp22_ = _ ("Invalid offset for node to start: for children number");
						_tmp23_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INDEX_SIZE_ERROR, _tmp22_);
						_inner_error_ = _tmp23_;
						g_propagate_error (error, _inner_error_);
						return;
					}
				}
			}
		}
	}
	_tmp24_ = self->_start_container;
	if (_tmp24_ != NULL) {
		GXmlDomNode* _tmp25_ = NULL;
		GXmlDomNode* _tmp26_ = NULL;
		GXmlDomNode* _tmp27_ = NULL;
		GXmlDomNode* _tmp28_ = NULL;
		GXmlDomNode* _tmp29_ = NULL;
		GXmlDomNode* _tmp30_ = NULL;
		GXmlDomNode* _tmp31_ = NULL;
		GXmlDomNode* _tmp32_ = NULL;
		gboolean _tmp33_ = FALSE;
		_tmp25_ = node;
		_tmp26_ = gxml_dom_node_get_parent_node (_tmp25_);
		_tmp27_ = _tmp26_;
		_tmp28_ = _tmp27_;
		_tmp29_ = self->_start_container;
		_tmp30_ = gxml_dom_node_get_parent_node (_tmp29_);
		_tmp31_ = _tmp30_;
		_tmp32_ = _tmp31_;
		_tmp33_ = _tmp28_ != _tmp32_;
		_g_object_unref0 (_tmp32_);
		_g_object_unref0 (_tmp28_);
		if (_tmp33_) {
			GXmlDomNode* _tmp34_ = NULL;
			GXmlDomNode* _tmp35_ = NULL;
			gint _tmp36_ = 0;
			_tmp34_ = self->_start_container;
			_tmp35_ = _g_object_ref0 (_tmp34_);
			_g_object_unref0 (self->_end_container);
			self->_end_container = _tmp35_;
			_tmp36_ = self->_start_offset;
			self->_end_offset = _tmp36_;
		} else {
			gint ni = 0;
			GXmlDomNode* _tmp37_ = NULL;
			GXmlDomNode* _tmp38_ = NULL;
			GXmlDomNode* _tmp39_ = NULL;
			GXmlDomNode* _tmp40_ = NULL;
			GXmlDomNodeList* _tmp41_ = NULL;
			GXmlDomNodeList* _tmp42_ = NULL;
			GXmlDomNodeList* _tmp43_ = NULL;
			GXmlDomNode* _tmp44_ = NULL;
			gint _tmp45_ = 0;
			gint _tmp46_ = 0;
			gint _tmp47_ = 0;
			gint _tmp48_ = 0;
			_tmp37_ = node;
			_tmp38_ = gxml_dom_node_get_parent_node (_tmp37_);
			_tmp39_ = _tmp38_;
			_tmp40_ = _tmp39_;
			_tmp41_ = gxml_dom_node_get_child_nodes (_tmp40_);
			_tmp42_ = _tmp41_;
			_tmp43_ = _tmp42_;
			_tmp44_ = node;
			_tmp45_ = gee_list_index_of ((GeeList*) _tmp43_, _tmp44_);
			_tmp46_ = _tmp45_;
			_g_object_unref0 (_tmp43_);
			_g_object_unref0 (_tmp40_);
			ni = _tmp46_;
			_tmp47_ = ni;
			_tmp48_ = offset;
			if (_tmp47_ > _tmp48_) {
				GXmlDomNode* _tmp49_ = NULL;
				GXmlDomNode* _tmp50_ = NULL;
				_tmp49_ = node;
				_tmp50_ = _g_object_ref0 (_tmp49_);
				_g_object_unref0 (self->_start_container);
				self->_start_container = _tmp50_;
			}
		}
	}
	_tmp51_ = node;
	_tmp52_ = _g_object_ref0 (_tmp51_);
	_g_object_unref0 (self->_end_container);
	self->_end_container = _tmp52_;
	_tmp53_ = offset;
	self->_end_offset = _tmp53_;
}


static void gxml_gdom_range_real_set_start_before (GXmlDomRange* base, GXmlDomNode* node, GError** error) {
	GXmlGDomRange * self;
	GXmlDomNode* _tmp0_ = NULL;
	GXmlDomNode* _tmp1_ = NULL;
	GXmlDomNode* _tmp2_ = NULL;
	GXmlDomNode* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	GXmlDomNode* _tmp7_ = NULL;
	GXmlDomNode* _tmp8_ = NULL;
	GXmlDomNode* _tmp9_ = NULL;
	GXmlDomNode* _tmp10_ = NULL;
	GXmlDomNode* _tmp11_ = NULL;
	GXmlDomNode* _tmp12_ = NULL;
	GXmlDomNode* _tmp13_ = NULL;
	GXmlDomNode* _tmp14_ = NULL;
	GXmlDomNodeList* _tmp15_ = NULL;
	GXmlDomNodeList* _tmp16_ = NULL;
	GXmlDomNodeList* _tmp17_ = NULL;
	GXmlDomNode* _tmp18_ = NULL;
	gint _tmp19_ = 0;
	GError * _inner_error_ = NULL;
	self = (GXmlGDomRange*) base;
	g_return_if_fail (node != NULL);
	_tmp0_ = node;
	_tmp1_ = gxml_dom_node_get_parent_node (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_ == NULL;
	_g_object_unref0 (_tmp3_);
	if (_tmp4_) {
		const gchar* _tmp5_ = NULL;
		GError* _tmp6_ = NULL;
		_tmp5_ = _ ("Invalid node type to start before");
		_tmp6_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR, _tmp5_);
		_inner_error_ = _tmp6_;
		g_propagate_error (error, _inner_error_);
		return;
	}
	_tmp7_ = node;
	_tmp8_ = gxml_dom_node_get_parent_node (_tmp7_);
	_tmp9_ = _tmp8_;
	_tmp10_ = _tmp9_;
	_tmp11_ = node;
	_tmp12_ = gxml_dom_node_get_parent_node (_tmp11_);
	_tmp13_ = _tmp12_;
	_tmp14_ = _tmp13_;
	_tmp15_ = gxml_dom_node_get_child_nodes (_tmp14_);
	_tmp16_ = _tmp15_;
	_tmp17_ = _tmp16_;
	_tmp18_ = node;
	_tmp19_ = gee_list_index_of ((GeeList*) _tmp17_, _tmp18_);
	gxml_dom_range_set_start ((GXmlDomRange*) self, _tmp10_, _tmp19_, &_inner_error_);
	_g_object_unref0 (_tmp17_);
	_g_object_unref0 (_tmp14_);
	_g_object_unref0 (_tmp10_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		return;
	}
}


static void gxml_gdom_range_real_set_start_after (GXmlDomRange* base, GXmlDomNode* node, GError** error) {
	GXmlGDomRange * self;
	GXmlDomNode* _tmp0_ = NULL;
	GXmlDomNode* _tmp1_ = NULL;
	GXmlDomNode* _tmp2_ = NULL;
	GXmlDomNode* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	gint i = 0;
	GXmlDomNode* _tmp7_ = NULL;
	GXmlDomNode* _tmp8_ = NULL;
	GXmlDomNode* _tmp9_ = NULL;
	GXmlDomNode* _tmp10_ = NULL;
	GXmlDomNodeList* _tmp11_ = NULL;
	GXmlDomNodeList* _tmp12_ = NULL;
	GXmlDomNodeList* _tmp13_ = NULL;
	GXmlDomNode* _tmp14_ = NULL;
	gint _tmp15_ = 0;
	gint _tmp16_ = 0;
	gint _tmp17_ = 0;
	GXmlDomNode* _tmp18_ = NULL;
	GXmlDomNode* _tmp19_ = NULL;
	GXmlDomNode* _tmp20_ = NULL;
	GXmlDomNode* _tmp21_ = NULL;
	GXmlDomNodeList* _tmp22_ = NULL;
	GXmlDomNodeList* _tmp23_ = NULL;
	GXmlDomNodeList* _tmp24_ = NULL;
	gint _tmp25_ = 0;
	gint _tmp26_ = 0;
	gboolean _tmp27_ = FALSE;
	GError * _inner_error_ = NULL;
	self = (GXmlGDomRange*) base;
	g_return_if_fail (node != NULL);
	_tmp0_ = node;
	_tmp1_ = gxml_dom_node_get_parent_node (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_ == NULL;
	_g_object_unref0 (_tmp3_);
	if (_tmp4_) {
		const gchar* _tmp5_ = NULL;
		GError* _tmp6_ = NULL;
		_tmp5_ = _ ("Invalid node type to start after");
		_tmp6_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR, _tmp5_);
		_inner_error_ = _tmp6_;
		g_propagate_error (error, _inner_error_);
		return;
	}
	_tmp7_ = node;
	_tmp8_ = gxml_dom_node_get_parent_node (_tmp7_);
	_tmp9_ = _tmp8_;
	_tmp10_ = _tmp9_;
	_tmp11_ = gxml_dom_node_get_child_nodes (_tmp10_);
	_tmp12_ = _tmp11_;
	_tmp13_ = _tmp12_;
	_tmp14_ = node;
	_tmp15_ = gee_list_index_of ((GeeList*) _tmp13_, _tmp14_);
	_tmp16_ = _tmp15_;
	_g_object_unref0 (_tmp13_);
	_g_object_unref0 (_tmp10_);
	i = _tmp16_;
	_tmp17_ = i;
	_tmp18_ = node;
	_tmp19_ = gxml_dom_node_get_parent_node (_tmp18_);
	_tmp20_ = _tmp19_;
	_tmp21_ = _tmp20_;
	_tmp22_ = gxml_dom_node_get_child_nodes (_tmp21_);
	_tmp23_ = _tmp22_;
	_tmp24_ = _tmp23_;
	_tmp25_ = gee_collection_get_size ((GeeCollection*) _tmp24_);
	_tmp26_ = _tmp25_;
	_tmp27_ = (_tmp17_ + 1) < _tmp26_;
	_g_object_unref0 (_tmp24_);
	_g_object_unref0 (_tmp21_);
	if (_tmp27_) {
		GXmlDomNode* _tmp28_ = NULL;
		GXmlDomNode* _tmp29_ = NULL;
		GXmlDomNode* _tmp30_ = NULL;
		GXmlDomNode* _tmp31_ = NULL;
		GXmlDomNode* _tmp32_ = NULL;
		GXmlDomNode* _tmp33_ = NULL;
		GXmlDomNode* _tmp34_ = NULL;
		GXmlDomNode* _tmp35_ = NULL;
		GXmlDomNodeList* _tmp36_ = NULL;
		GXmlDomNodeList* _tmp37_ = NULL;
		GXmlDomNodeList* _tmp38_ = NULL;
		GXmlDomNode* _tmp39_ = NULL;
		gint _tmp40_ = 0;
		_tmp28_ = node;
		_tmp29_ = gxml_dom_node_get_parent_node (_tmp28_);
		_tmp30_ = _tmp29_;
		_tmp31_ = _tmp30_;
		_tmp32_ = node;
		_tmp33_ = gxml_dom_node_get_parent_node (_tmp32_);
		_tmp34_ = _tmp33_;
		_tmp35_ = _tmp34_;
		_tmp36_ = gxml_dom_node_get_child_nodes (_tmp35_);
		_tmp37_ = _tmp36_;
		_tmp38_ = _tmp37_;
		_tmp39_ = node;
		_tmp40_ = gee_list_index_of ((GeeList*) _tmp38_, _tmp39_);
		gxml_dom_range_set_start ((GXmlDomRange*) self, _tmp31_, _tmp40_ + 1, &_inner_error_);
		_g_object_unref0 (_tmp38_);
		_g_object_unref0 (_tmp35_);
		_g_object_unref0 (_tmp31_);
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			g_propagate_error (error, _inner_error_);
			return;
		}
	} else {
		GXmlDomNode* _tmp41_ = NULL;
		GXmlDomNode* _tmp42_ = NULL;
		GXmlDomNode* _tmp43_ = NULL;
		GXmlDomNode* _tmp44_ = NULL;
		GXmlDomNode* _tmp45_ = NULL;
		GXmlDomNode* _tmp46_ = NULL;
		GXmlDomNode* _tmp47_ = NULL;
		GXmlDomNode* _tmp48_ = NULL;
		GXmlDomNodeList* _tmp49_ = NULL;
		GXmlDomNodeList* _tmp50_ = NULL;
		GXmlDomNodeList* _tmp51_ = NULL;
		GXmlDomNode* _tmp52_ = NULL;
		gint _tmp53_ = 0;
		_tmp41_ = node;
		_tmp42_ = gxml_dom_node_get_parent_node (_tmp41_);
		_tmp43_ = _tmp42_;
		_tmp44_ = _tmp43_;
		_tmp45_ = node;
		_tmp46_ = gxml_dom_node_get_parent_node (_tmp45_);
		_tmp47_ = _tmp46_;
		_tmp48_ = _tmp47_;
		_tmp49_ = gxml_dom_node_get_child_nodes (_tmp48_);
		_tmp50_ = _tmp49_;
		_tmp51_ = _tmp50_;
		_tmp52_ = node;
		_tmp53_ = gee_list_index_of ((GeeList*) _tmp51_, _tmp52_);
		gxml_dom_range_set_start ((GXmlDomRange*) self, _tmp44_, _tmp53_, &_inner_error_);
		_g_object_unref0 (_tmp51_);
		_g_object_unref0 (_tmp48_);
		_g_object_unref0 (_tmp44_);
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			g_propagate_error (error, _inner_error_);
			return;
		}
	}
}


static void gxml_gdom_range_real_set_end_before (GXmlDomRange* base, GXmlDomNode* node, GError** error) {
	GXmlGDomRange * self;
	GXmlDomNode* _tmp0_ = NULL;
	GXmlDomNode* _tmp1_ = NULL;
	GXmlDomNode* _tmp2_ = NULL;
	GXmlDomNode* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	GXmlDomNode* _tmp7_ = NULL;
	GXmlDomNode* _tmp8_ = NULL;
	GXmlDomNode* _tmp9_ = NULL;
	GXmlDomNode* _tmp10_ = NULL;
	GXmlDomNode* _tmp11_ = NULL;
	GXmlDomNode* _tmp12_ = NULL;
	GXmlDomNode* _tmp13_ = NULL;
	GXmlDomNode* _tmp14_ = NULL;
	GXmlDomNodeList* _tmp15_ = NULL;
	GXmlDomNodeList* _tmp16_ = NULL;
	GXmlDomNodeList* _tmp17_ = NULL;
	GXmlDomNode* _tmp18_ = NULL;
	gint _tmp19_ = 0;
	GError * _inner_error_ = NULL;
	self = (GXmlGDomRange*) base;
	g_return_if_fail (node != NULL);
	_tmp0_ = node;
	_tmp1_ = gxml_dom_node_get_parent_node (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_ == NULL;
	_g_object_unref0 (_tmp3_);
	if (_tmp4_) {
		const gchar* _tmp5_ = NULL;
		GError* _tmp6_ = NULL;
		_tmp5_ = _ ("Invalid node type to start before");
		_tmp6_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR, _tmp5_);
		_inner_error_ = _tmp6_;
		g_propagate_error (error, _inner_error_);
		return;
	}
	_tmp7_ = node;
	_tmp8_ = gxml_dom_node_get_parent_node (_tmp7_);
	_tmp9_ = _tmp8_;
	_tmp10_ = _tmp9_;
	_tmp11_ = node;
	_tmp12_ = gxml_dom_node_get_parent_node (_tmp11_);
	_tmp13_ = _tmp12_;
	_tmp14_ = _tmp13_;
	_tmp15_ = gxml_dom_node_get_child_nodes (_tmp14_);
	_tmp16_ = _tmp15_;
	_tmp17_ = _tmp16_;
	_tmp18_ = node;
	_tmp19_ = gee_list_index_of ((GeeList*) _tmp17_, _tmp18_);
	gxml_dom_range_set_end ((GXmlDomRange*) self, _tmp10_, _tmp19_, &_inner_error_);
	_g_object_unref0 (_tmp17_);
	_g_object_unref0 (_tmp14_);
	_g_object_unref0 (_tmp10_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		return;
	}
}


static void gxml_gdom_range_real_set_end_after (GXmlDomRange* base, GXmlDomNode* node, GError** error) {
	GXmlGDomRange * self;
	GXmlDomNode* _tmp0_ = NULL;
	GXmlDomNode* _tmp1_ = NULL;
	GXmlDomNode* _tmp2_ = NULL;
	GXmlDomNode* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	gint i = 0;
	GXmlDomNode* _tmp7_ = NULL;
	GXmlDomNode* _tmp8_ = NULL;
	GXmlDomNode* _tmp9_ = NULL;
	GXmlDomNode* _tmp10_ = NULL;
	GXmlDomNodeList* _tmp11_ = NULL;
	GXmlDomNodeList* _tmp12_ = NULL;
	GXmlDomNodeList* _tmp13_ = NULL;
	GXmlDomNode* _tmp14_ = NULL;
	gint _tmp15_ = 0;
	gint _tmp16_ = 0;
	gint _tmp17_ = 0;
	GXmlDomNode* _tmp18_ = NULL;
	GXmlDomNode* _tmp19_ = NULL;
	GXmlDomNode* _tmp20_ = NULL;
	GXmlDomNode* _tmp21_ = NULL;
	GXmlDomNodeList* _tmp22_ = NULL;
	GXmlDomNodeList* _tmp23_ = NULL;
	GXmlDomNodeList* _tmp24_ = NULL;
	gint _tmp25_ = 0;
	gint _tmp26_ = 0;
	gboolean _tmp27_ = FALSE;
	GError * _inner_error_ = NULL;
	self = (GXmlGDomRange*) base;
	g_return_if_fail (node != NULL);
	_tmp0_ = node;
	_tmp1_ = gxml_dom_node_get_parent_node (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_ == NULL;
	_g_object_unref0 (_tmp3_);
	if (_tmp4_) {
		const gchar* _tmp5_ = NULL;
		GError* _tmp6_ = NULL;
		_tmp5_ = _ ("Invalid node type to start after");
		_tmp6_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR, _tmp5_);
		_inner_error_ = _tmp6_;
		g_propagate_error (error, _inner_error_);
		return;
	}
	_tmp7_ = node;
	_tmp8_ = gxml_dom_node_get_parent_node (_tmp7_);
	_tmp9_ = _tmp8_;
	_tmp10_ = _tmp9_;
	_tmp11_ = gxml_dom_node_get_child_nodes (_tmp10_);
	_tmp12_ = _tmp11_;
	_tmp13_ = _tmp12_;
	_tmp14_ = node;
	_tmp15_ = gee_list_index_of ((GeeList*) _tmp13_, _tmp14_);
	_tmp16_ = _tmp15_;
	_g_object_unref0 (_tmp13_);
	_g_object_unref0 (_tmp10_);
	i = _tmp16_;
	_tmp17_ = i;
	_tmp18_ = node;
	_tmp19_ = gxml_dom_node_get_parent_node (_tmp18_);
	_tmp20_ = _tmp19_;
	_tmp21_ = _tmp20_;
	_tmp22_ = gxml_dom_node_get_child_nodes (_tmp21_);
	_tmp23_ = _tmp22_;
	_tmp24_ = _tmp23_;
	_tmp25_ = gee_collection_get_size ((GeeCollection*) _tmp24_);
	_tmp26_ = _tmp25_;
	_tmp27_ = (_tmp17_ + 1) < _tmp26_;
	_g_object_unref0 (_tmp24_);
	_g_object_unref0 (_tmp21_);
	if (_tmp27_) {
		GXmlDomNode* _tmp28_ = NULL;
		GXmlDomNode* _tmp29_ = NULL;
		GXmlDomNode* _tmp30_ = NULL;
		GXmlDomNode* _tmp31_ = NULL;
		GXmlDomNode* _tmp32_ = NULL;
		GXmlDomNode* _tmp33_ = NULL;
		GXmlDomNode* _tmp34_ = NULL;
		GXmlDomNode* _tmp35_ = NULL;
		GXmlDomNodeList* _tmp36_ = NULL;
		GXmlDomNodeList* _tmp37_ = NULL;
		GXmlDomNodeList* _tmp38_ = NULL;
		GXmlDomNode* _tmp39_ = NULL;
		gint _tmp40_ = 0;
		_tmp28_ = node;
		_tmp29_ = gxml_dom_node_get_parent_node (_tmp28_);
		_tmp30_ = _tmp29_;
		_tmp31_ = _tmp30_;
		_tmp32_ = node;
		_tmp33_ = gxml_dom_node_get_parent_node (_tmp32_);
		_tmp34_ = _tmp33_;
		_tmp35_ = _tmp34_;
		_tmp36_ = gxml_dom_node_get_child_nodes (_tmp35_);
		_tmp37_ = _tmp36_;
		_tmp38_ = _tmp37_;
		_tmp39_ = node;
		_tmp40_ = gee_list_index_of ((GeeList*) _tmp38_, _tmp39_);
		gxml_dom_range_set_end ((GXmlDomRange*) self, _tmp31_, _tmp40_ + 1, &_inner_error_);
		_g_object_unref0 (_tmp38_);
		_g_object_unref0 (_tmp35_);
		_g_object_unref0 (_tmp31_);
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			g_propagate_error (error, _inner_error_);
			return;
		}
	} else {
		GXmlDomNode* _tmp41_ = NULL;
		GXmlDomNode* _tmp42_ = NULL;
		GXmlDomNode* _tmp43_ = NULL;
		GXmlDomNode* _tmp44_ = NULL;
		GXmlDomNode* _tmp45_ = NULL;
		GXmlDomNode* _tmp46_ = NULL;
		GXmlDomNode* _tmp47_ = NULL;
		GXmlDomNode* _tmp48_ = NULL;
		GXmlDomNodeList* _tmp49_ = NULL;
		GXmlDomNodeList* _tmp50_ = NULL;
		GXmlDomNodeList* _tmp51_ = NULL;
		GXmlDomNode* _tmp52_ = NULL;
		gint _tmp53_ = 0;
		_tmp41_ = node;
		_tmp42_ = gxml_dom_node_get_parent_node (_tmp41_);
		_tmp43_ = _tmp42_;
		_tmp44_ = _tmp43_;
		_tmp45_ = node;
		_tmp46_ = gxml_dom_node_get_parent_node (_tmp45_);
		_tmp47_ = _tmp46_;
		_tmp48_ = _tmp47_;
		_tmp49_ = gxml_dom_node_get_child_nodes (_tmp48_);
		_tmp50_ = _tmp49_;
		_tmp51_ = _tmp50_;
		_tmp52_ = node;
		_tmp53_ = gee_list_index_of ((GeeList*) _tmp51_, _tmp52_);
		gxml_dom_range_set_end ((GXmlDomRange*) self, _tmp44_, _tmp53_, &_inner_error_);
		_g_object_unref0 (_tmp51_);
		_g_object_unref0 (_tmp48_);
		_g_object_unref0 (_tmp44_);
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			g_propagate_error (error, _inner_error_);
			return;
		}
	}
}


static void gxml_gdom_range_real_collapse (GXmlDomRange* base, gboolean to_start, GError** error) {
	GXmlGDomRange * self;
	gboolean _tmp0_ = FALSE;
	self = (GXmlGDomRange*) base;
	_tmp0_ = to_start;
	if (_tmp0_) {
		GXmlDomNode* _tmp1_ = NULL;
		GXmlDomNode* _tmp2_ = NULL;
		gint _tmp3_ = 0;
		_tmp1_ = self->_start_container;
		_tmp2_ = _g_object_ref0 (_tmp1_);
		_g_object_unref0 (self->_end_container);
		self->_end_container = _tmp2_;
		_tmp3_ = self->_start_offset;
		self->_end_offset = _tmp3_;
	} else {
		GXmlDomNode* _tmp4_ = NULL;
		GXmlDomNode* _tmp5_ = NULL;
		gint _tmp6_ = 0;
		_tmp4_ = self->_end_container;
		_tmp5_ = _g_object_ref0 (_tmp4_);
		_g_object_unref0 (self->_start_container);
		self->_start_container = _tmp5_;
		_tmp6_ = self->_end_offset;
		self->_start_offset = _tmp6_;
	}
}


static void gxml_gdom_range_real_select_node (GXmlDomRange* base, GXmlDomNode* node, GError** error) {
	GXmlGDomRange * self;
	GXmlDomNode* _tmp0_ = NULL;
	GXmlDomNode* _tmp1_ = NULL;
	GXmlDomNode* _tmp2_ = NULL;
	GXmlDomNode* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	gint i = 0;
	GXmlDomNode* _tmp7_ = NULL;
	GXmlDomNode* _tmp8_ = NULL;
	GXmlDomNode* _tmp9_ = NULL;
	GXmlDomNode* _tmp10_ = NULL;
	GXmlDomNodeList* _tmp11_ = NULL;
	GXmlDomNodeList* _tmp12_ = NULL;
	GXmlDomNodeList* _tmp13_ = NULL;
	GXmlDomNode* _tmp14_ = NULL;
	gint _tmp15_ = 0;
	gint _tmp16_ = 0;
	GXmlDomNode* _tmp17_ = NULL;
	GXmlDomNode* _tmp18_ = NULL;
	GXmlDomNode* _tmp19_ = NULL;
	GXmlDomNode* _tmp20_ = NULL;
	gint _tmp21_ = 0;
	gint _tmp22_ = 0;
	GXmlDomNode* _tmp23_ = NULL;
	GXmlDomNode* _tmp24_ = NULL;
	GXmlDomNode* _tmp25_ = NULL;
	GXmlDomNode* _tmp26_ = NULL;
	GXmlDomNodeList* _tmp27_ = NULL;
	GXmlDomNodeList* _tmp28_ = NULL;
	GXmlDomNodeList* _tmp29_ = NULL;
	gint _tmp30_ = 0;
	gint _tmp31_ = 0;
	gboolean _tmp32_ = FALSE;
	GError * _inner_error_ = NULL;
	self = (GXmlGDomRange*) base;
	g_return_if_fail (node != NULL);
	_tmp0_ = node;
	_tmp1_ = gxml_dom_node_get_parent_node (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_ == NULL;
	_g_object_unref0 (_tmp3_);
	if (_tmp4_) {
		const gchar* _tmp5_ = NULL;
		GError* _tmp6_ = NULL;
		_tmp5_ = _ ("Invalid node type to start after");
		_tmp6_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR, _tmp5_);
		_inner_error_ = _tmp6_;
		g_propagate_error (error, _inner_error_);
		return;
	}
	_tmp7_ = node;
	_tmp8_ = gxml_dom_node_get_parent_node (_tmp7_);
	_tmp9_ = _tmp8_;
	_tmp10_ = _tmp9_;
	_tmp11_ = gxml_dom_node_get_child_nodes (_tmp10_);
	_tmp12_ = _tmp11_;
	_tmp13_ = _tmp12_;
	_tmp14_ = node;
	_tmp15_ = gee_list_index_of ((GeeList*) _tmp13_, _tmp14_);
	_tmp16_ = _tmp15_;
	_g_object_unref0 (_tmp13_);
	_g_object_unref0 (_tmp10_);
	i = _tmp16_;
	_tmp17_ = node;
	_tmp18_ = gxml_dom_node_get_parent_node (_tmp17_);
	_tmp19_ = _tmp18_;
	_tmp20_ = _tmp19_;
	_tmp21_ = i;
	gxml_dom_range_set_start ((GXmlDomRange*) self, _tmp20_, _tmp21_, &_inner_error_);
	_g_object_unref0 (_tmp20_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		return;
	}
	_tmp22_ = i;
	_tmp23_ = node;
	_tmp24_ = gxml_dom_node_get_parent_node (_tmp23_);
	_tmp25_ = _tmp24_;
	_tmp26_ = _tmp25_;
	_tmp27_ = gxml_dom_node_get_child_nodes (_tmp26_);
	_tmp28_ = _tmp27_;
	_tmp29_ = _tmp28_;
	_tmp30_ = gee_collection_get_size ((GeeCollection*) _tmp29_);
	_tmp31_ = _tmp30_;
	_tmp32_ = (_tmp22_ + 1) < _tmp31_;
	_g_object_unref0 (_tmp29_);
	_g_object_unref0 (_tmp26_);
	if (_tmp32_) {
		GXmlDomNode* _tmp33_ = NULL;
		GXmlDomNode* _tmp34_ = NULL;
		GXmlDomNode* _tmp35_ = NULL;
		GXmlDomNode* _tmp36_ = NULL;
		gint _tmp37_ = 0;
		_tmp33_ = node;
		_tmp34_ = gxml_dom_node_get_parent_node (_tmp33_);
		_tmp35_ = _tmp34_;
		_tmp36_ = _tmp35_;
		_tmp37_ = i;
		gxml_dom_range_set_end ((GXmlDomRange*) self, _tmp36_, _tmp37_ + 1, &_inner_error_);
		_g_object_unref0 (_tmp36_);
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			g_propagate_error (error, _inner_error_);
			return;
		}
	} else {
		GXmlDomNode* _tmp38_ = NULL;
		GXmlDomNode* _tmp39_ = NULL;
		GXmlDomNode* _tmp40_ = NULL;
		GXmlDomNode* _tmp41_ = NULL;
		gint _tmp42_ = 0;
		_tmp38_ = node;
		_tmp39_ = gxml_dom_node_get_parent_node (_tmp38_);
		_tmp40_ = _tmp39_;
		_tmp41_ = _tmp40_;
		_tmp42_ = i;
		gxml_dom_range_set_end ((GXmlDomRange*) self, _tmp41_, _tmp42_, &_inner_error_);
		_g_object_unref0 (_tmp41_);
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			g_propagate_error (error, _inner_error_);
			return;
		}
	}
}


static void gxml_gdom_range_real_select_node_contents (GXmlDomRange* base, GXmlDomNode* node, GError** error) {
	GXmlGDomRange * self;
	GXmlDomNode* _tmp0_ = NULL;
	GXmlDomNode* _tmp3_ = NULL;
	gint length = 0;
	GXmlDomNode* _tmp4_ = NULL;
	GXmlDomNode* _tmp15_ = NULL;
	gint _tmp16_ = 0;
	GError * _inner_error_ = NULL;
	self = (GXmlGDomRange*) base;
	g_return_if_fail (node != NULL);
	_tmp0_ = node;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT_TYPE)) {
		const gchar* _tmp1_ = NULL;
		GError* _tmp2_ = NULL;
		_tmp1_ = _ ("Invalid node type to start");
		_tmp2_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR, _tmp1_);
		_inner_error_ = _tmp2_;
		g_propagate_error (error, _inner_error_);
		return;
	}
	_tmp3_ = node;
	gxml_dom_range_set_start ((GXmlDomRange*) self, _tmp3_, 0, &_inner_error_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		return;
	}
	length = 0;
	_tmp4_ = node;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GXML_TYPE_DOCUMENT_TYPE)) {
		length = 0;
	} else {
		GXmlDomNode* _tmp5_ = NULL;
		_tmp5_ = node;
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GXML_TYPE_DOM_CHARACTER_DATA)) {
			GXmlDomNode* _tmp6_ = NULL;
			gint _tmp7_ = 0;
			gint _tmp8_ = 0;
			_tmp6_ = node;
			_tmp7_ = gxml_dom_character_data_get_length (G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, GXML_TYPE_DOM_CHARACTER_DATA) ? ((GXmlDomCharacterData*) _tmp6_) : NULL);
			_tmp8_ = _tmp7_;
			length = _tmp8_;
		} else {
			GXmlDomNode* _tmp9_ = NULL;
			GXmlDomNodeList* _tmp10_ = NULL;
			GXmlDomNodeList* _tmp11_ = NULL;
			GXmlDomNodeList* _tmp12_ = NULL;
			gint _tmp13_ = 0;
			gint _tmp14_ = 0;
			_tmp9_ = node;
			_tmp10_ = gxml_dom_node_get_child_nodes (_tmp9_);
			_tmp11_ = _tmp10_;
			_tmp12_ = _tmp11_;
			_tmp13_ = gxml_dom_node_list_get_length (_tmp12_);
			_tmp14_ = _tmp13_;
			length = _tmp14_;
			_g_object_unref0 (_tmp12_);
		}
	}
	_tmp15_ = node;
	_tmp16_ = length;
	gxml_dom_range_set_end ((GXmlDomRange*) self, _tmp15_, _tmp16_, &_inner_error_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		return;
	}
}


static gint gxml_gdom_range_real_compare_boundary_points (GXmlDomRange* base, GXmlDomRangeBoundaryPoints how, GXmlDomRange* source_range, GError** error) {
	GXmlGDomRange * self;
	gint result = 0;
	GXmlDomNode* _tmp0_ = NULL;
	GXmlDomNode* _tmp1_ = NULL;
	GXmlDomNode* _tmp2_ = NULL;
	GXmlDomNode* _tmp3_ = NULL;
	GXmlDomRange* _tmp4_ = NULL;
	GXmlDomNode* _tmp5_ = NULL;
	GXmlDomNode* _tmp6_ = NULL;
	GXmlDomNode* _tmp7_ = NULL;
	GXmlDomNode* _tmp8_ = NULL;
	GXmlDomNode* _tmp9_ = NULL;
	gboolean _tmp10_ = FALSE;
	GXmlDomRangeBoundaryPoints _tmp14_ = 0;
	GError * _inner_error_ = NULL;
	self = (GXmlGDomRange*) base;
	g_return_val_if_fail (source_range != NULL, 0);
	_tmp0_ = self->_start_container;
	_tmp1_ = gxml_dom_node_get_parent_node (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp4_ = source_range;
	_tmp5_ = gxml_dom_range_get_start_container (_tmp4_);
	_tmp6_ = _tmp5_;
	_tmp7_ = gxml_dom_node_get_parent_node (_tmp6_);
	_tmp8_ = _tmp7_;
	_tmp9_ = _tmp8_;
	_tmp10_ = _tmp3_ != _tmp9_;
	_g_object_unref0 (_tmp9_);
	_g_object_unref0 (_tmp3_);
	if (_tmp10_) {
		const gchar* _tmp11_ = NULL;
		GError* _tmp12_ = NULL;
		gint _tmp13_ = 0;
		_tmp11_ = _ ("Invalid root in the source range");
		_tmp12_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_WRONG_DOCUMENT_ERROR, _tmp11_);
		_inner_error_ = _tmp12_;
		g_propagate_error (error, _inner_error_);
		return _tmp13_;
	}
	_tmp14_ = how;
	switch (_tmp14_) {
		case GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_START:
		{
			GXmlDomNode* _tmp15_ = NULL;
			GXmlDomRange* _tmp17_ = NULL;
			GXmlDomNode* _tmp18_ = NULL;
			GXmlDomNode* _tmp19_ = NULL;
			_tmp15_ = self->_start_container;
			gxml_dom_range_set_start ((GXmlDomRange*) self, _tmp15_, 0, &_inner_error_);
			if (G_UNLIKELY (_inner_error_ != NULL)) {
				gint _tmp16_ = 0;
				g_propagate_error (error, _inner_error_);
				return _tmp16_;
			}
			_tmp17_ = source_range;
			_tmp18_ = gxml_dom_range_get_start_container (_tmp17_);
			_tmp19_ = _tmp18_;
			gxml_dom_range_set_end ((GXmlDomRange*) self, _tmp19_, 0, &_inner_error_);
			if (G_UNLIKELY (_inner_error_ != NULL)) {
				gint _tmp20_ = 0;
				g_propagate_error (error, _inner_error_);
				return _tmp20_;
			}
			result = 0;
			return result;
		}
		case GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_END:
		{
			GXmlDomNode* _tmp21_ = NULL;
			GXmlDomNode* _tmp22_ = NULL;
			GXmlDomNodeList* _tmp23_ = NULL;
			GXmlDomNodeList* _tmp24_ = NULL;
			GXmlDomNodeList* _tmp25_ = NULL;
			gint _tmp26_ = 0;
			gint _tmp27_ = 0;
			GXmlDomRange* _tmp29_ = NULL;
			GXmlDomNode* _tmp30_ = NULL;
			GXmlDomNode* _tmp31_ = NULL;
			_tmp21_ = self->_start_container;
			_tmp22_ = self->_start_container;
			_tmp23_ = gxml_dom_node_get_child_nodes (_tmp22_);
			_tmp24_ = _tmp23_;
			_tmp25_ = _tmp24_;
			_tmp26_ = gee_collection_get_size ((GeeCollection*) _tmp25_);
			_tmp27_ = _tmp26_;
			gxml_dom_range_set_start ((GXmlDomRange*) self, _tmp21_, _tmp27_, &_inner_error_);
			_g_object_unref0 (_tmp25_);
			if (G_UNLIKELY (_inner_error_ != NULL)) {
				gint _tmp28_ = 0;
				g_propagate_error (error, _inner_error_);
				return _tmp28_;
			}
			_tmp29_ = source_range;
			_tmp30_ = gxml_dom_range_get_end_container (_tmp29_);
			_tmp31_ = _tmp30_;
			gxml_dom_range_set_end ((GXmlDomRange*) self, _tmp31_, 0, &_inner_error_);
			if (G_UNLIKELY (_inner_error_ != NULL)) {
				gint _tmp32_ = 0;
				g_propagate_error (error, _inner_error_);
				return _tmp32_;
			}
			result = -1;
			return result;
		}
		case GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_END:
		{
			GXmlDomNode* _tmp33_ = NULL;
			GXmlDomRange* _tmp35_ = NULL;
			GXmlDomNode* _tmp36_ = NULL;
			GXmlDomNode* _tmp37_ = NULL;
			_tmp33_ = self->_end_container;
			gxml_dom_range_set_start ((GXmlDomRange*) self, _tmp33_, 0, &_inner_error_);
			if (G_UNLIKELY (_inner_error_ != NULL)) {
				gint _tmp34_ = 0;
				g_propagate_error (error, _inner_error_);
				return _tmp34_;
			}
			_tmp35_ = source_range;
			_tmp36_ = gxml_dom_range_get_end_container (_tmp35_);
			_tmp37_ = _tmp36_;
			gxml_dom_range_set_end ((GXmlDomRange*) self, _tmp37_, 0, &_inner_error_);
			if (G_UNLIKELY (_inner_error_ != NULL)) {
				gint _tmp38_ = 0;
				g_propagate_error (error, _inner_error_);
				return _tmp38_;
			}
			result = 0;
			return result;
		}
		case GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_START:
		{
			GXmlDomNode* _tmp39_ = NULL;
			GXmlDomRange* _tmp41_ = NULL;
			GXmlDomNode* _tmp42_ = NULL;
			GXmlDomNode* _tmp43_ = NULL;
			_tmp39_ = self->_start_container;
			gxml_dom_range_set_start ((GXmlDomRange*) self, _tmp39_, 0, &_inner_error_);
			if (G_UNLIKELY (_inner_error_ != NULL)) {
				gint _tmp40_ = 0;
				g_propagate_error (error, _inner_error_);
				return _tmp40_;
			}
			_tmp41_ = source_range;
			_tmp42_ = gxml_dom_range_get_end_container (_tmp41_);
			_tmp43_ = _tmp42_;
			gxml_dom_range_set_end ((GXmlDomRange*) self, _tmp43_, 0, &_inner_error_);
			if (G_UNLIKELY (_inner_error_ != NULL)) {
				gint _tmp44_ = 0;
				g_propagate_error (error, _inner_error_);
				return _tmp44_;
			}
			result = 1;
			return result;
		}
		default:
		break;
	}
	result = 0;
	return result;
}


static void gxml_gdom_range_real_delete_contents (GXmlDomRange* base, GError** error) {
	GXmlGDomRange * self;
	self = (GXmlGDomRange*) base;
	return;
}


static GXmlDomDocumentFragment* gxml_gdom_range_real_extract_contents (GXmlDomRange* base, GError** error) {
	GXmlGDomRange * self;
	GXmlDomDocumentFragment* result = NULL;
	self = (GXmlGDomRange*) base;
	result = NULL;
	return result;
}


static GXmlDomDocumentFragment* gxml_gdom_range_real_clone_contents (GXmlDomRange* base, GError** error) {
	GXmlGDomRange * self;
	GXmlDomDocumentFragment* result = NULL;
	self = (GXmlGDomRange*) base;
	result = NULL;
	return result;
}


static void gxml_gdom_range_real_insert_node (GXmlDomRange* base, GXmlDomNode* node) {
	GXmlGDomRange * self;
	self = (GXmlGDomRange*) base;
	g_return_if_fail (node != NULL);
	return;
}


static void gxml_gdom_range_real_surround_contents (GXmlDomRange* base, GXmlDomNode* newParent) {
	GXmlGDomRange * self;
	self = (GXmlGDomRange*) base;
	g_return_if_fail (newParent != NULL);
	return;
}


static GXmlDomRange* gxml_gdom_range_real_clone_range (GXmlDomRange* base) {
	GXmlGDomRange * self;
	GXmlDomRange* result = NULL;
	GObject* _tmp0_ = NULL;
	GXmlDomRange* _tmp1_ = NULL;
	self = (GXmlGDomRange*) base;
	_tmp0_ = g_object_ref ((GObject*) self);
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GXML_TYPE_DOM_RANGE, GXmlDomRange));
	result = _tmp1_;
	return result;
}


static void gxml_gdom_range_real_detach (GXmlDomRange* base) {
	GXmlGDomRange * self;
	self = (GXmlGDomRange*) base;
	return;
}


static gboolean gxml_gdom_range_real_is_point_in_range (GXmlDomRange* base, GXmlDomNode* node, gint offset) {
	GXmlGDomRange * self;
	gboolean result = FALSE;
	self = (GXmlGDomRange*) base;
	g_return_val_if_fail (node != NULL, FALSE);
	result = FALSE;
	return result;
}


static gshort gxml_gdom_range_real_compare_point (GXmlDomRange* base, GXmlDomNode* node, gint offset) {
	GXmlGDomRange * self;
	gshort result = 0;
	self = (GXmlGDomRange*) base;
	g_return_val_if_fail (node != NULL, 0);
	result = (gshort) 0;
	return result;
}


static gboolean gxml_gdom_range_real_intersects_node (GXmlDomRange* base, GXmlDomNode* node) {
	GXmlGDomRange * self;
	gboolean result = FALSE;
	self = (GXmlGDomRange*) base;
	g_return_val_if_fail (node != NULL, FALSE);
	result = FALSE;
	return result;
}


static gchar* gxml_gdom_range_real_to_string (GXmlDomRange* base) {
	GXmlGDomRange * self;
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
	self = (GXmlGDomRange*) base;
	_tmp0_ = g_strdup ("DomRange");
	result = _tmp0_;
	return result;
}


static GXmlDomNode* gxml_gdom_range_real_get_start_container (GXmlDomRange* base) {
	GXmlDomNode* result;
	GXmlGDomRange* self;
	GXmlDomNode* _tmp0_ = NULL;
	self = (GXmlGDomRange*) base;
	_tmp0_ = self->_start_container;
	result = _tmp0_;
	return result;
}


static gint gxml_gdom_range_real_get_start_offset (GXmlDomRange* base) {
	gint result;
	GXmlGDomRange* self;
	gint _tmp0_ = 0;
	self = (GXmlGDomRange*) base;
	_tmp0_ = self->_start_offset;
	result = _tmp0_;
	return result;
}


static GXmlDomNode* gxml_gdom_range_real_get_end_container (GXmlDomRange* base) {
	GXmlDomNode* result;
	GXmlGDomRange* self;
	GXmlDomNode* _tmp0_ = NULL;
	self = (GXmlGDomRange*) base;
	_tmp0_ = self->_end_container;
	result = _tmp0_;
	return result;
}


static gint gxml_gdom_range_real_get_end_offset (GXmlDomRange* base) {
	gint result;
	GXmlGDomRange* self;
	gint _tmp0_ = 0;
	self = (GXmlGDomRange*) base;
	_tmp0_ = self->_end_offset;
	result = _tmp0_;
	return result;
}


static gboolean gxml_gdom_range_real_get_collapsed (GXmlDomRange* base) {
	gboolean result;
	GXmlGDomRange* self;
	gboolean _tmp0_ = FALSE;
	self = (GXmlGDomRange*) base;
	_tmp0_ = self->_collapse;
	result = _tmp0_;
	return result;
}


static GXmlDomNode* gxml_gdom_range_real_get_common_ancestor_container (GXmlDomRange* base) {
	GXmlDomNode* result;
	GXmlGDomRange* self;
	GXmlDomNode* _tmp0_ = NULL;
	self = (GXmlGDomRange*) base;
	_tmp0_ = self->_common_ancestor_container;
	result = _tmp0_;
	return result;
}


static void gxml_gdom_range_class_init (GXmlGDomRangeClass * klass) {
	gxml_gdom_range_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gdom_range_get_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_gdom_range_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOM_RANGE_START_CONTAINER, g_param_spec_object ("start-container", "start-container", "start-container", GXML_TYPE_DOM_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOM_RANGE_START_OFFSET, g_param_spec_int ("start-offset", "start-offset", "start-offset", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOM_RANGE_END_CONTAINER, g_param_spec_object ("end-container", "end-container", "end-container", GXML_TYPE_DOM_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOM_RANGE_END_OFFSET, g_param_spec_int ("end-offset", "end-offset", "end-offset", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOM_RANGE_COLLAPSED, g_param_spec_boolean ("collapsed", "collapsed", "collapsed", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GDOM_RANGE_COMMON_ANCESTOR_CONTAINER, g_param_spec_object ("common-ancestor-container", "common-ancestor-container", "common-ancestor-container", GXML_TYPE_DOM_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
}


static void gxml_gdom_range_gxml_dom_range_interface_init (GXmlDomRangeIface * iface) {
	gxml_gdom_range_gxml_dom_range_parent_iface = g_type_interface_peek_parent (iface);
	iface->set_start = (void (*)(GXmlDomRange*, GXmlDomNode*, gint, GError**)) gxml_gdom_range_real_set_start;
	iface->set_end = (void (*)(GXmlDomRange*, GXmlDomNode*, gint, GError**)) gxml_gdom_range_real_set_end;
	iface->set_start_before = (void (*)(GXmlDomRange*, GXmlDomNode*, GError**)) gxml_gdom_range_real_set_start_before;
	iface->set_start_after = (void (*)(GXmlDomRange*, GXmlDomNode*, GError**)) gxml_gdom_range_real_set_start_after;
	iface->set_end_before = (void (*)(GXmlDomRange*, GXmlDomNode*, GError**)) gxml_gdom_range_real_set_end_before;
	iface->set_end_after = (void (*)(GXmlDomRange*, GXmlDomNode*, GError**)) gxml_gdom_range_real_set_end_after;
	iface->collapse = (void (*)(GXmlDomRange*, gboolean, GError**)) gxml_gdom_range_real_collapse;
	iface->select_node = (void (*)(GXmlDomRange*, GXmlDomNode*, GError**)) gxml_gdom_range_real_select_node;
	iface->select_node_contents = (void (*)(GXmlDomRange*, GXmlDomNode*, GError**)) gxml_gdom_range_real_select_node_contents;
	iface->compare_boundary_points = (gint (*)(GXmlDomRange*, GXmlDomRangeBoundaryPoints, GXmlDomRange*, GError**)) gxml_gdom_range_real_compare_boundary_points;
	iface->delete_contents = (void (*)(GXmlDomRange*, GError**)) gxml_gdom_range_real_delete_contents;
	iface->extract_contents = (GXmlDomDocumentFragment* (*)(GXmlDomRange*, GError**)) gxml_gdom_range_real_extract_contents;
	iface->clone_contents = (GXmlDomDocumentFragment* (*)(GXmlDomRange*, GError**)) gxml_gdom_range_real_clone_contents;
	iface->insert_node = (void (*)(GXmlDomRange*, GXmlDomNode*)) gxml_gdom_range_real_insert_node;
	iface->surround_contents = (void (*)(GXmlDomRange*, GXmlDomNode*)) gxml_gdom_range_real_surround_contents;
	iface->clone_range = (GXmlDomRange* (*)(GXmlDomRange*)) gxml_gdom_range_real_clone_range;
	iface->detach = (void (*)(GXmlDomRange*)) gxml_gdom_range_real_detach;
	iface->is_point_in_range = (gboolean (*)(GXmlDomRange*, GXmlDomNode*, gint)) gxml_gdom_range_real_is_point_in_range;
	iface->compare_point = (gshort (*)(GXmlDomRange*, GXmlDomNode*, gint)) gxml_gdom_range_real_compare_point;
	iface->intersects_node = (gboolean (*)(GXmlDomRange*, GXmlDomNode*)) gxml_gdom_range_real_intersects_node;
	iface->to_string = (gchar* (*)(GXmlDomRange*)) gxml_gdom_range_real_to_string;
	iface->get_start_container = gxml_gdom_range_real_get_start_container;
	iface->get_start_offset = gxml_gdom_range_real_get_start_offset;
	iface->get_end_container = gxml_gdom_range_real_get_end_container;
	iface->get_end_offset = gxml_gdom_range_real_get_end_offset;
	iface->get_collapsed = gxml_gdom_range_real_get_collapsed;
	iface->get_common_ancestor_container = gxml_gdom_range_real_get_common_ancestor_container;
}


static void gxml_gdom_range_instance_init (GXmlGDomRange * self) {
}


static void gxml_gdom_range_finalize (GObject* obj) {
	GXmlGDomRange * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GDOM_RANGE, GXmlGDomRange);
	_g_object_unref0 (self->_document);
	_g_object_unref0 (self->_start_container);
	_g_object_unref0 (self->_end_container);
	_g_object_unref0 (self->_common_ancestor_container);
	G_OBJECT_CLASS (gxml_gdom_range_parent_class)->finalize (obj);
}


GType gxml_gdom_range_get_type (void) {
	static volatile gsize gxml_gdom_range_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gdom_range_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGDomRangeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gdom_range_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGDomRange), 0, (GInstanceInitFunc) gxml_gdom_range_instance_init, NULL };
		static const GInterfaceInfo gxml_dom_range_info = { (GInterfaceInitFunc) gxml_gdom_range_gxml_dom_range_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_gdom_range_type_id;
		gxml_gdom_range_type_id = g_type_register_static (G_TYPE_OBJECT, "GXmlGDomRange", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_gdom_range_type_id, GXML_TYPE_DOM_RANGE, &gxml_dom_range_info);
		g_once_init_leave (&gxml_gdom_range_type_id__volatile, gxml_gdom_range_type_id);
	}
	return gxml_gdom_range_type_id__volatile;
}


static void _vala_gxml_gdom_range_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGDomRange * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GDOM_RANGE, GXmlGDomRange);
	switch (property_id) {
		case GXML_GDOM_RANGE_START_CONTAINER:
		g_value_set_object (value, gxml_dom_range_get_start_container ((GXmlDomRange*) self));
		break;
		case GXML_GDOM_RANGE_START_OFFSET:
		g_value_set_int (value, gxml_dom_range_get_start_offset ((GXmlDomRange*) self));
		break;
		case GXML_GDOM_RANGE_END_CONTAINER:
		g_value_set_object (value, gxml_dom_range_get_end_container ((GXmlDomRange*) self));
		break;
		case GXML_GDOM_RANGE_END_OFFSET:
		g_value_set_int (value, gxml_dom_range_get_end_offset ((GXmlDomRange*) self));
		break;
		case GXML_GDOM_RANGE_COLLAPSED:
		g_value_set_boolean (value, gxml_dom_range_get_collapsed ((GXmlDomRange*) self));
		break;
		case GXML_GDOM_RANGE_COMMON_ANCESTOR_CONTAINER:
		g_value_set_object (value, gxml_dom_range_get_common_ancestor_container ((GXmlDomRange*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}



